/**
 * 
 * 用户列表
 */
import React, { Component } from 'react'
import { ManOutlined, WomanOutlined } from '@ant-design/icons';
import { Card, Table, Divider, Button, Drawer } from 'antd';
import styles from './SelectUser.less'
// 引入接口
import { getUserList, } from '@/services/manage'
// 引入模块公用组件
import Filters from './Filters'
// 引入公用函数
import { getDate, showSuccess, showError } from '@/utils/base'
// 引入模块公用函数
import { reportStatus, getStatusStr } from './common'
// 引入的图片展示组件
import ZImage from 'react-zmage'

// table 
const Column = Table.Column
// 底部按钮样式
const _btnStyle = {
  width: 110,
  margin: '0 10px'
}
class SelectUser extends Component {
  constructor (props) {
    super(props)
    this.state = {
      // 加载列表 loading
      loading: false,
      // 列表数据
      list: [],
      // 姓名
      userName: '',
      // 状态
      handleStatus: undefined,
      // 存放全部选择的
      choosenStore: [],
      // 分页
      pagination: {
        current: 1
      },
      selectedRows: [],
      selectedRowKeys: [],
    }
  }
  componentDidMount () {
    this.getList()
  }
  
  // 获取列表
  getList = async () => {
    const _state = {
      loading: false
    }
    try {
      const { 
        userName, userNo, userPhone, pagination, isAnchor, sortType,
        userStatus, niceNo, startTime, endTime
      } = this.state
      // 页码，每页条数
      const _params = {
        pageNum: pagination.current || 1,
        pageSize: 10,
      }
      // 名字
      if (userName) {
        // _params.pageNum = 1
        _params.userName = userName
      }

      // 靓号
      if (niceNo) {
        _params.niceNo = niceNo
      }

      // 星芽号
      if (userNo) {
        _params.userNo = userNo
      }

      // 手机号
      if (userPhone) {
        _params.userPhone = userPhone
      }

      // 是否主播
      if (isAnchor && isAnchor !== 'all') {
        _params.isAnchor = isAnchor
      }

      // 排序方式
      if (sortType) {
        _params.sortType = sortType
      }

      // 用户状态
      if (userStatus !== 'all' && userStatus) {
        _params.userStatus = userStatus
      }

      // 时间
      if (startTime) {
        _params.startTime = startTime
        _params.endTime = endTime
      }

      this.setState({ loading: true })
      const { data, code } = await getUserList(_params)
      if (code === 'OK' && data) {
        const { list, total, pageIndex, pageSize } = data
        _state.list = list
        _state.pagination = {
          current: pageIndex,
          total: total,
          pageSize: pageSize
        }
      }
    } catch (e) {
      console.log(e)
    }
    this.setState(_state)
  }

  // 子组建内容变化
  onChange = (name, value) => {
    if (Array.isArray(name)) {
      let _state = {}
      name.map((item) => {
        _state[item.name] = item.value
      })
      this.setState(_state)
      return
    }
    this.setState({ [name]: value })
  }
  // 搜索
  onSearch = () => {
    const { pagination } = this.state 
    pagination.current = 1
    this.setState({ pagination }, this.getList)
  }

  // 获取处理状态
  getStatus = (handleStatus) => {
    const obj = reportStatus.find(item => item.key === handleStatus)
    return obj ? obj.value : '-'
  }

  onPageChange = (pagination) => {
    this.setState({ pagination }, this.getList)
  }

  // 选择
  onSelect = (selectedRowKeys, selectedRows) => {
    const { choosenStore } = this.state
    this.setState({ selectedRowKeys, choosenStore: choosenStore.concat(selectedRows) })
  }

  onOk = () => {
    const { choosenStore, selectedRowKeys } = this.state
    const { onOk } = this.props 
    const _choosen = selectedRowKeys.map(item => choosenStore.find(subItem => item === subItem.userId))
    onOk && onOk(_choosen)
  }

  render () {
    const { onCancel, type } = this.props
    const { 
      loading, list, userName, userPhone, niceNo, userStatus, pagination,
      startTime, endTime, userNo, sortType, isAnchor, uploading, selectedRowKeys
    } = this.state
    const { total, current, pageSize } = pagination
    const hidePagination = current === 1 && pageSize >= total

    const rowSelection = {
      selectedRowKeys,
      type: type || 'radio',
      onChange: this.onSelect
      // onSelect: (record, selected, selectedRows) => {
      //   this.onSelect(selectedRows)
      // },
      // onSelectAll: (selected, selectedRows, changeRows) => {
      //   this.onSelect(selectedRows)
      // },
    }
    return (
      <Drawer 
        title='用户选择'
        visible
        width={1200}
        onClose={onCancel}
      >
        <div className={styles['content-wrap']}>
          <Filters 
            status={reportStatus}
            onChange={this.onChange}
            userName={userName}
            userNo={userNo}
            niceNo={niceNo}
            sortType={sortType}
            userStatus={userStatus}
            userPhone={userPhone}
            isAnchor={isAnchor}
            onSearch={this.onSearch}
            startTime={startTime}
            endTime={endTime}
          />
          <Table
            loading={loading}
            dataSource={list}
            rowKey='userId'
            onChange={this.onPageChange}
            bordered
            pagination={hidePagination ? false : pagination}
            rowSelection={rowSelection}
          >
            <Column 
              title='头像'
              key='userAvatar'
              dataIndex='userAvatar'
              render={(text, { userAvatar}) => (
                userAvatar
                ? <ZImage src={userAvatar} style={{width: 60}} />
                : '-'
              )}
            />
            <Column 
              title='星芽号'
              key='userNo'
              dataIndex='userNo'
            />
            <Column 
              title='昵称'
              key='userName'
              dataIndex='userName'
            />
            <Column 
              title='性别'
              key='userSex'
              dataIndex='userSex'
              render={userSex => (
                userSex === 1 
                ? <ManOutlined style={{ color: '#1890ff' }} /> 
                : userSex === 2
                  ? <WomanOutlined style={{ color: '#eb2f96' }} />
                  : '-'
              )}
            />
            <Column 
              title='手机号'
              key='userPhone'
              dataIndex='userPhone'
              render={text => text || '-'}
            />
            <Column 
              title='是否主播'
              key='isAnchor'
              dataIndex='isAnchor'
              render={(text, { isAnchor }) => (
                <div>{isAnchor === 1 ? '是' : '否'}</div>
              )}
            />
            <Column 
              title='财富等级'
              key='wealthLevel'
              dataIndex='wealthLevel'
            />
            <Column 
              title='魅力等级'
              key='charmLevel'
              dataIndex='charmLevel'
            />
            <Column 
              title='注册时间'
              key='userCreateTime'
              dataIndex='userCreateTime'
              render={(text, { userCreateTime }) => (
                <div>
                  {userCreateTime && userCreateTime !== '0' ? getDate(+userCreateTime, 'yyyy-MM-dd hh:mm') : '-'}
                </div>
              )}
            />
            <Column 
              title='状态'
              key='userStatus'
              dataIndex='userStatus'
              render={(text, { userStatus }) => (
                <div>{getStatusStr(userStatus)}</div>
              )}
            />
          </Table>
          <div className={styles['footer-wrap']}>
            <Button 
              style={_btnStyle}
              onClick={onCancel}
            >取消</Button>
            <Button 
              type='primary' 
              style={_btnStyle}
              onClick={uploading ? null : this.onOk}
            >确定</Button>
          </div>
        </div>
      </Drawer>
    );
  }
}
export default SelectUser
