/**
 * 
 * 用户的单聊记录
 */
import React, { memo, useEffect, useState } from 'react'
import { Card, Table } from 'antd'
import { getDate } from '@/utils/base'
import { getUserTagList } from '@/services/common'
const Column = Table.Column
const _style = {
  marginBottom: 10
}
const SingChatRecord = memo(({ userId }) => {
  const [records, setRecords] = useState();
  useEffect(() => {
    if (!userId) {
      return
    }
    getUserTagList({userId})
    .then(({ code, data }) => {
      if (code === 'OK') {
        setRecords(data)
      }
    })
  }, [userId])
  const hasRecords = records && records.length !== 0
  return (
    hasRecords
    ? <Card title='单聊评价标签' style={_style}>
      <Table
        dataSource={records}
        bordered
        pagination={false}
        rowKey={(record, i) => i}
      >
        <Column 
          title='用户名称'
          dataIndex='userName'
          key='userName'
        />
        <Column 
          title='用户ID'
          dataIndex='userId'
          key='userId'
        />
        <Column 
          title='标签名称'
          dataIndex='tagName'
          key='tagName'
        />
        <Column 
          title='标签ID'
          dataIndex='tagId'
          key='tagId'
        />
        <Column 
          title='次数'
          dataIndex='tagCount'
          key='tagCount'
        />
        <Column 
          title='评价时间'
          dataIndex='updateTime'
          key='updateTime'
          render={(text, { updateTime }) => (
            updateTime
            ? getDate(+updateTime)
            : '-'
          )}
        />
      </Table>
    </Card>
    : ''
  )
})
export default SingChatRecord
