import { queryCurrent, query as queryUsers, getUserInfo } from '@/services/user';
import { setAuthority } from '@/utils/authority';

const UserModel = {
  namespace: 'user',
  state: {
    currentUser: {},
    userLoading: true,
  },
  effects: {
    *fetch(_, { call, put }) {
      const response = yield call(queryUsers);
      yield put({
        type: 'save',
        payload: response,
      });
    },

    *fetchCurrent(_, { call, put }) {
      try {
        yield put({
          type: 'loading',
          payload: {
            userLoading: true
          }
        })
        const response = yield call(getUserInfo);
        // 用户信息获取不成功 直接return掉
        if (!response || response.code !== 'OK') {
          return
        }
        //设置可以查看时段统计权限
        if (response.data.channelGroupId) {
          setAuthority('manager');
        }
        yield put({
          type: 'saveCurrentUser',
          payload: response.data || {},
        });
        yield put({
          type: 'loading',
          payload: {
            userLoading: false
          }
        })
      } catch (e) {
        console.log(e)
      }
    },
  },
  reducers: {
    saveCurrentUser(state, action) {
      return { ...state, currentUser: action.payload || {} };
    },

    changeNotifyCount(
      state = {
        currentUser: {},
      },
      action,
    ) {
      return {
        ...state,
        currentUser: {
          ...state.currentUser,
          notifyCount: action.payload.totalCount,
          unreadCount: action.payload.unreadCount,
        },
      };
    },
    loading(state, { payload }) {
      return Object.assign({}, state, payload)
    }
  },
};
export default UserModel;
