import React, { Fragment } from 'react';
import { Row, Button, Descriptions, Card } from 'antd';
import { getChannelApp, getChannelinformation } from './services/api';
import { PageHeaderWrapper } from '@ant-design/pro-layout';
import Zmage from 'react-zmage';
import SecretKeyList from './components/SecretKeyList'
import { SettingOutlined } from '@ant-design/icons'
import UpdateAppInfo from './components/UpdateAppInfo'
import Channelinstallation from './components/Channelinstallation';
import router from 'umi/router';
import Url from '@/utils/Url'
import { RSASecret } from './RSASecret'

const defaultInstall = {
  channelName: "星芽",
  todayInstallRatio: '无返回值',
  todaySplitRatio: '无返回值',
  tomorrowInstallRatio: '无返回值',
  tomorrowSplitRatio: '无返回值',
}
class ChannelInfo extends React.Component {
  constructor(props) {
    super(props);
    this.state = {
      loading: false,
      info: {},
      appIcon: [],
      installData: {},
      channelId: Url.getQueryString('channelId')
    };
  }

  async componentDidMount() {
    this.getChannelApp(); //获取渠道APP
  }
  //获取渠道APP
  getChannelApp = () => {
    this.setState({ loading: true }, async () => {
      const res = await getChannelApp({ channelId: this.state.channelId });
      //获取渠道分成比例信息
      const installationData = await getChannelinformation({ channelId: this.state.channelId });
      if (res.success && installationData.success) {
        const info = res.data || {};
        const appIcon = info.appIcon || []
        const installData = installationData.data || defaultInstall;
        this.setState({ loading: false, info, appIcon, installData });
      } else {
        this.setState({ loading: false });
      }
    });
  }
  //获取渠道分成比例信息
  onUpdateinstallation = async () => {
    this.setState({ loading: true }, async () => {
      const getData = await getChannelinformation({ channelId: this.state.channelId });
      if (getData.success) {
        const installData = getData.data || defaultInstall;
        this.setState({ installData, loading: false })
      }
      else {
        this.setState({ loading: false })
      }
    })
  }
  testLog() {
    console.log(this.state);
  }

  onRefresh = () => {
    this.setState({ updateModal: false })
    this.getChannelApp()
  }

  render() {
    const { loading, info, appIcon, installData, channelId } = this.state;
    return (
      <PageHeaderWrapper
        title={<span onClick={this.testLog.bind(this)}>渠道详情</span>}
        onBack={() => router.goBack()}
      >
        <Channelinstallation
          onGetdata={this.onUpdateinstallation}
          loading={loading}
          installData={installData}
          channelId={channelId}
        />
        <Card loading={loading}
          title="渠道APP"
          extra={
            <Button type="primary" icon={<SettingOutlined />} onClick={() => this.setState({ updateModal: true })}>编辑</Button>
          }
        >
          <Descriptions bordered>
            <Descriptions.Item label="图标">
              <Row align="middle">
                {appIcon[0] && (
                  <div>
                    <Zmage
                      style={{ width: 50, height: 50, borderRadius: '50%' }}
                      src={appIcon[0].x57_57}
                    ></Zmage>
                    <div>57*57</div>
                  </div>
                )}
                {appIcon[1] && (
                  <div style={{ marginLeft: 20 }}>
                    <Zmage
                      style={{ width: 50, height: 50, borderRadius: '50%' }}
                      src={appIcon[1].x512_512}
                    ></Zmage>
                    <div>512*512</div>
                  </div>
                )}
              </Row>
            </Descriptions.Item>
            <Descriptions.Item label="名称">{info.appName}</Descriptions.Item>
            <Descriptions.Item label="App 手机登陆服务地址">
              {info.apiAuthByPhone || '--'}
            </Descriptions.Item>
            <Descriptions.Item label="星芽注册用户通知对方url">
              {info.apiNoticeUserRegistered || '--'}
            </Descriptions.Item>
            <Descriptions.Item label="星芽用户修改信息通知对方Url">
              {info.apiNoticeUserUpdate || '--'}
            </Descriptions.Item>
          </Descriptions>
        </Card>
        <div style={{ marginTop: 30 }}>
          <SecretKeyList channelId={channelId} />
        </div>
        <div style={{ marginTop: 30 }}>
          <RSASecret 
            channelId={channelId} 
          />
        </div>

        {this.state.updateModal && (
          <UpdateAppInfo
            channelId={channelId}
            info={this.state.info}
            drawerProps={{
              width: 600,
              title: '编辑App信息',
              visible: this.state.updateModal,
              onClose: () => this.setState({ updateModal: false }),
            }}
            refresh={this.onRefresh}
          />
        )}
      </PageHeaderWrapper>
    );
  }
}

export default ChannelInfo;

