{/* <AddManager
  info={this.state.info}
  drawerProps={{
    width: 600,
    title: this.state.actionType === 'add' ? '添加子账号' : '编辑子账号',
    visible: this.state.actionModal,
    onClose: () => this.setState({ actionModal: false }),
  }}
  refresh={() => {
    this.setState({ actionModal: false })
    this.getAdminPageList(1)
  }}
  type={this.state.actionType}
/> */}


import React, { useState, Fragment, useEffect } from 'react'
import '@ant-design/compatible/assets/index.css';
import { Drawer, Button, Input, notification, Form, Radio, message, Select } from 'antd';
import FooterToolbar from '@/components/FooterToolbar'
import { createAdmin, editAdmin } from '../../services/api'
import { objFilter } from '@/utils/Help';
import Security from '@/utils/Security'
import { connect } from 'dva'

const Option = Select.Option
const FormItem = Form.Item;
const formItemLayout = {
  labelCol: {
    xs: {
      span: 24,
    },
    sm: {
      span: 12,
    },
  },
  wrapperCol: {
    xs: {
      span: 24,
    },
    sm: {
      span: 12,
    },
    md: {
      span: 10,
    },
  },
};

const formRef = React.createRef()

//添加-编辑子账号
function AddManager(props) {

  const [updateLoading, setUpdateLoading] = useState(false)

  useEffect(() => {
    const { info, type, drawerProps } = props;
    if (type === 'update' && drawerProps.visible) {
      formRef.current.setFieldsValue({
        adminName: info.adminName,
        adminPhone: info.adminPhone,
        adminEmail: info.adminEmail,
        status: info.adminStatus
      })
    }
    if (props.drawerProps.visible === false) {
      formRef.current.resetFields()
    }
  }, [props.drawerProps.visible])

  //添加 - 编辑
  const onSubmit = () => {
    const { type, info } = props
    formRef.current.validateFields().then(async (values) => {
      console.log(values)
      if (values.adminPass2 !== values.adminPass) {
        message.error('确认密码不一致')
        return
      }
      const params = {
        ...values,
        authChannelIds: values.authChannelIds.join(','),
      }
      if (type === 'add') {
        params.adminPass = Security.encryptMd5(values.adminPass)
        delete params.adminPass2
      } else {
        params.adminId = info.adminId
      }
      objFilter(params)
      await setUpdateLoading(true)
      const res = type === 'add' ? await createAdmin(params) : await editAdmin(params)
      setUpdateLoading(false)
      if (res.success) {
        notification.success({
          message: type === 'add' ? '添加成功' : '编辑成功'
        })
        props.refresh()
      }
    })
  }

  const textLog = () => {
    console.log(props)
    //console.log(formRef.current.getFieldsValue())
  }

  const { drawerProps, type, info, dispatch } = props
  return (
    <Form ref={formRef} {...formItemLayout}>
      <Drawer {...drawerProps}>
        <FormItem
          label={<span onClick={textLog}>子账号名称</span>}
          name="adminName"
          rules={[{ required: true, message: '请输入子账号名称' }]}
        >
          <Input placeholder="请输入子账号名称" allowClear />
        </FormItem>
        <FormItem
          label="手机号"
          name="adminPhone"
          rules={[{ required: true, message: '请输入手机号' }]}
        >
          <Input placeholder="请输入手机号" allowClear />
        </FormItem>
        <FormItem
          label="邮箱"
          name="adminEmail"
          rules={[{ required: false, message: '请输入邮箱' }]}
        >
          <Input placeholder="请输入邮箱" allowClear />
        </FormItem>

        {type === 'add' && (
          <Fragment>
            <FormItem
              label="登录密码"
              name="adminPass"
              rules={[{ required: true, message: '请输入登录密码' }]}
            >
              <Input.Password placeholder="请输入登录密码" allowClear />
            </FormItem>

            <FormItem
              label="确认密码"
              name="adminPass2"
              rules={[{ required: true, message: '请输入确认密码' }]}
            >
              <Input.Password placeholder="请输入确认密码" allowClear />
            </FormItem>
          </Fragment>
        )}

        <FormItem
          label="状态"
          name="status"
          rules={[{ required: true, message: '请选择状态' }]}
        >
          <Radio.Group>
            <Radio value={1}>启用</Radio>
            <Radio value={0} style={{ marginLeft: 20 }}>禁用</Radio>
          </Radio.Group>
        </FormItem>
        {/* 选择授权渠道 */}
        <SelectChannel
          info={info}
          type={type}
          form={formRef.current}
          visible={drawerProps.visible}
          dispatch={dispatch}
          list={props.channel.channelListByGroupId}
        />

        <FooterToolbar style={{ position: 'absolute' }}>
          <Button type="primary" loading={updateLoading} onClick={onSubmit}>
            {type === 'add' ? '确定添加' : '确定编辑'}
          </Button>
        </FooterToolbar>
      </Drawer>
    </Form>
  )
}

export default connect(channel => channel)(AddManager)

//选择授权渠道
function SelectChannel(props) {
  const { info, type, visible, dispatch, list } = props

  //初始化获取下拉渠道选项
  useEffect(() => {
    console.log(props)
    dispatch({
      type: 'channel/fetchChannelListByGroupId',
    });
  }, [])

  useEffect(() => {
    if (visible && type === 'update') {
      console.log()
      props.form.setFieldsValue({
        authChannelIds: (info.authChannelIds && type === 'update') ? info.authChannelIds.split(',') : undefined
      })
    }
  }, [list, visible])


  return (
    <FormItem
      label="授权渠道"
      name="authChannelIds"
      rules={[{ required: true, message: '请选授权渠道' }]}
    >
      <Select placeholder="请选择授权的渠道" mode="multiple">
        {list.map((item, i) => {
          return (
            <Option key={item.channelId} value={item.channelId}>{item.channelName}</Option>
          )
        })}
      </Select>
    </FormItem>

  )
}