/**
 * 
 * 异步回调配置
 */
import React, { Component } from 'react'
import { PageHeaderWrapper } from '@ant-design/pro-layout'
import styles from './NotifyConfig.less'
import { getNotifyConfigInfo } from './services/api'
import { Card, Alert, Tabs } from 'antd'
// import LineWrap from './components/LineWrap'
import RedEnvelop from './components/RedEnvelop'
import { notifyConfigTypeArray, getDate, showSuccess } from '@/utils/base'
import UpdateNotify from './components/UpdateNotify'
import router from 'umi/router'

const { TabPane } = Tabs

class NotifyConfig extends Component {
  constructor (props) {
    super(props)
    this.state = {
      apiNo: '10'
    }
    this.dataMap = new Map()
  }
  componentDidMount () {
    this.getNotifyConfigInfo()
  }
  getNotifyConfigInfo = async () => {
    const _state = {}
    const { apiNo } = this.state
    try {
      const { code, data } = await getNotifyConfigInfo({ apiNo })
      if (code === 'OK' && data) {
        const dataInfo = {}
        const { hostUrl, detail = {}, createTime, updateTime } = data 
        dataInfo.hostUrl = hostUrl
        dataInfo.createTime = createTime ? getDate(+createTime) : ''
        dataInfo.updateTime = updateTime ? getDate(+updateTime) : ''
        Object.assign(dataInfo, detail)
        this.dataMap.set(apiNo, dataInfo)
      }
    } catch (e) {
      console.log(e)
    }
    this.setState(_state)
  }
  // 编辑回调配置
  onEdit = apiNo => e => {
    if (apiNo === '10') {
      const { hostUrl } = this.dataMap.get('10') 
      // 红包异步通知配置
      UpdateNotify({
        apiNoStr: '红包异步通知',
        apiNo,
        hostUrl,
        onOk: () => {
          this.getNotifyConfigInfo()
          showSuccess('配置成功')
        }
      })
    }
  }
  // 跳转到回调记录列表
  goRecords = (apiNo) => e => {
    const pathname = '/channel/notifyConfig/records'
    const query = {}
    if (apiNo === '10') {
      query.apiNo = '10'
    }
    router.push({
      pathname,
      query
    })
  }
  onTabChange = (key) => {
    this.setState({ apiNo: key })
  }
  render () {
    const { apiNo } = this.state
    return (
      <PageHeaderWrapper>
        <Card>
          <Alert message="若未配置公钥，请先前往 '渠道管理 > 子渠道 > 详情' 进行配置" type='warning' />
          <Tabs activeKey={apiNo} onChange={this.onTabChange}>
            <TabPane tab='红包异步通知' key={'10'}>
              <RedEnvelop 
                {...this.dataMap.get('10')}
                onEdit={this.onEdit('10')}
                goRecords={this.goRecords('10')}
              />
            </TabPane>
          </Tabs>
        </Card>
      </PageHeaderWrapper>
    )
  }
}
export default NotifyConfig
