/**
 * 
 * 回调记录
 */
import React, { Component } from 'react'
import { PageHeaderWrapper } from '@ant-design/pro-layout'
import styles from './NotifyRecords.less'
import { Button, Card, Table, Popconfirm } from 'antd'
import { PlusOutlined, LeftOutlined } from '@ant-design/icons'
import { NotifyRecordsFilters } from './components'
import { channelNotifyHis, resendNotification } from './services/api'
import { showSuccess, getDate, getNotifyConfigTypeStr } from '@/utils/base'
import router from 'umi/router'
import { getRedEvelopResultStr } from './common'

const Column = Table.Column

class NotifyRecords extends Component {
  constructor (props) {
    super(props)
    const { apiNo } = props.location.query
    this.state = {
      apiNo,
      pageTitle: getNotifyConfigTypeStr(apiNo),
      pagination: {
        current: 1
      }
    }
  }
  componentDidMount () {
    this.getList()
  }
  
  getList = async () => {
    const _state = { loading: false }
    try {
      const { pagination, tradeId, startTime, endTime, isSuccess } = this.state
      const _params = {
        pageIndex: pagination.current || 1,
        pageSize: 20
      }
      if (tradeId) {
        _params.tradeId = tradeId
      }
      if (isSuccess === 0 || isSuccess) {
        _params.isSuccess = isSuccess
      }
      if (startTime) {
        _params.startTime = startTime
        _params.emdTime = endTime
      }
      this.setState({ loading: true })
      const { code, data } = await channelNotifyHis(_params)
      if (code === 'OK' && data) {
        const { list, pageIndex, pageSize, total } = data
        list && list.forEach((item) => {
          item.createTimeStr = item.createTime ? getDate(+item.createTime) : '-'
          item.isSuccessStr = getRedEvelopResultStr(item.isSuccess)
          item.resIsSuccessStr = item.resIsSuccess === 1 ? '成功' : '失败'
        })
        _state.records = list
        _state.pagination = {
          current: pageIndex,
          pageSize, 
          total
        }
      }
    } catch (e) {
      console.log(e)
    }
    this.setState(_state)
  }

  onPageChange = (pagination) => {
    this.setState({ pagination }, this.getList)
  }

  // 子组建内容变化
  onChange = (name, value) => {
    if (Array.isArray(name)) {
      let _state = {}
      name.map((item) => {
        _state[item.name] = item.value
      })
      this.setState(_state)
      return
    }
    this.setState({ [name]: value })
  }

  // 点击搜索
  onSearch = () => {
    const { pagination } = this.state 
    pagination.current = 1
    this.setState({ pagination }, this.getList)
  }

  // 返回
  goBack = () => {
    router.goBack()
  }

  // 重发通知
  onResend = record => async (event) => {
    const { hisId } = record
    const _state = {
      resending: false
    }
    // 防止重复点击
    if (this.state.resending) {
      return
    }
    try {
      const _params = {
        hisId
      }
      this.setState({ resending: true })
      const { code } = await resendNotification(_params)
      if (code === 'OK') {
        showSuccess('重发操作执行成功')
        // 
        this.getList()
      }
    } catch (e) {
      console.log(e)
    }
    this.setState(_state)
  }

  render () {
    const { 
      isSuccess, tradeId, startTime, endTime, records, pagination,
      loading, pageTitle
    } = this.state
    // 页码信息
    const { total, current, pageSize } = pagination
    // 石否隐藏 分页信息
    const hidePagination = current === 1 && pageSize >= total
    return (
      <PageHeaderWrapper
        title='异步通记录'
        extra={
          <div hidden>
            <Button
              icon={<LeftOutlined />}
              onClick={this.goBack}
            >返回</Button>
          </div>
        }
      >
        <Card>
          <NotifyRecordsFilters 
            isSuccess={isSuccess}
            tradeId={tradeId}
            startTime={startTime}
            endTime={endTime}
            onChange={this.onChange}
            onSearch={this.onSearch}
          />
          <Table
            bordered
            dataSource={records}
            rowKey='hisId'
            pagination={hidePagination ? false : pagination}
            onChange={this.onPageChange}
            loading={loading}
            className={styles['list-wrap']}
          >
            <Column 
              title='接口编号'
              key='apiNo'
              dataIndex='apiNo'
            />
            <Column 
              title='发红包记录ID'
              key='traceId'
              dataIndex='traceId'
            />
            <Column 
              title='通知地址'
              key='notifyUrl'
              dataIndex='notifyUrl'
              width='14%'
              render={(notifyUrl) => (notifyUrl || '-')}
            />
            <Column 
              title='通知数据'
              key='notifyData'
              dataIndex='notifyData'
              width='18%'
              render={(notifyData) => (notifyData || '-')}
            />
            <Column 
              title='通知次数'
              key='notifyTimes'
              dataIndex='notifyTimes'
              render={(notifyTimes) => (notifyTimes)}
            />
            <Column 
              title='处理结果'
              key='isSuccessStr'
              dataIndex='isSuccessStr'
            />
            <Column 
              title='响应结果'
              key='response'
              dataIndex='response'
              width='18%'
            />
            <Column 
              title='响应是否成功'
              key='resIsSuccessStr'
              dataIndex='resIsSuccessStr'
            />
            
            <Column 
              title='调用时长(ms)'
              key='callDuration'
              dataIndex='callDuration'
            />
            <Column 
              title='创建时间'
              key='createTimeStr'
              dataIndex='createTimeStr'
            />
            <Column 
              title='操作'
              key='action'
              dataIndex='action'
              render={(text, record) => (
                <div className={styles['list-actions']}>
                  <Popconfirm
                    title='确定要重发该条通知吗？'
                    onConfirm={this.onResend(record)}
                    okText='是'
                    cancelText='否'
                  >
                    <a href="#" onClick={ e=> {
                      e.preventDefault()
                    } }>重发</a>
                  </Popconfirm>
                </div>
              )}
            />
          </Table>
        </Card>
      </PageHeaderWrapper>
    )
  }
}
export default NotifyRecords
