/**
 * 创建/更新 公钥
 */
import React, { Component } from 'react'
import styles from './CreateSecretDrawer.less'
import { Drawer, Button, Input, Form } from 'antd'
import { updateRSAInfo } from '../services/api'

const FormItem = Form.Item;
const formItemLayout = {
  labelCol: { xs: { span: 24, }, sm: { span: 6, }, },
  wrapperCol: { 
    xs: { span: 24, },
    sm: { span: 14, },
    md: { span: 14, },
  },
};

// 底部按钮样式
const _btnStyle = {
  width: 110,
  margin: '0 10px'
}

class CreateSecretDrawer extends Component {
  constructor (props) {
    super(props)
    this.state = {
      uploading: false,
      xyPubKey: ''
    }
  }
  formRef = React.createRef()
  componentDidMount () {
    
  }
  
  onOk = async () => {
    try {
      const values = await this.formRef.current.validateFields()
      const { onOk, channelId } = this.props
      values.channelId = channelId
      const { code } = await updateRSAInfo(values)
      if (code === 'OK'){
        // 更新成功
        onOk && onOk()
      }
    } catch (e) {
      console.log(e)
    }
  }
  render () {
    const { uploading, pubKey } = this.state
    const { onCancel } = this.props
    return (
      <Drawer
        width={520}
        visible
        title={pubKey ? '更新RSA公钥' : '创建RSA公钥' }
        onClose={onCancel}
      >
        <div className={styles['content-wrap']}>
          <Form ref={this.formRef} {...formItemLayout}>
            
            <FormItem
              label="公钥"
              name="pubKey"
              rules={[{ required: true, message: '请输入公钥' }]}
            >
              <Input.TextArea 
                placeholder='请输入公钥' 
                rows={6}
              />
            </FormItem>
          </Form>
          <div className={styles['footer-wrap']}>
            <Button
              style={_btnStyle}
              onClick={onCancel}
            >取消</Button>
            <Button
              type='primary'
              style={_btnStyle}
              onClick={uploading ? null : this.onOk}
            >确定</Button>
          </div>
        </div>
      </Drawer>
    )
  }
}
export default CreateSecretDrawer
