import React, { Component } from 'react'
import styles from './RSASecret.less'
import { Card, Button, Descriptions } from 'antd'
import { PlusOutlined } from '@ant-design/icons'
import CreateSecret from './CreateSecret'
import { getRSAInfo } from '../services/api'
import { showSuccess, getDate } from '@/utils/base'

class RSASecret extends Component {
  constructor (props) {
    super(props)
    this.state = {}
  }
  componentDidMount () {
    this.getRSAInfo()
  }
  onCreateSecret = () => {
    const { channelId } = this.props
    const { pubKey } = this.state
    CreateSecret({ 
      channelId,
      pubKey,
      onOk: () => {
        showSuccess('密钥添加成功')
        this.getRSAInfo()
      }
    })
  }
  getRSAInfo = async () => {
    const { channelId } = this.props
    const _state = {}
    try {
      const { code, data } = await getRSAInfo({ channelId })
      if (code === 'OK' && data) {
        const { xyPubKey, pubKey, updateTime, createTime } = data
        _state.xyPubKey = xyPubKey
        _state.pubKey = pubKey
        _state.updateTime = updateTime ? getDate(+updateTime) : ''
        _state.createTime = createTime ? getDate(+createTime) : ''
      }
    } catch (e) {
      console.log(e)
    }
    this.setState(_state)
  }
  render () {
    const { pubKey, xyPubKey, updateTime, createTime } = this.state
    return (
      <Card
        title='RSA公钥'
        extra={
          <div>
            <Button
              icon={<PlusOutlined />}
              type='primary'
              onClick
              ={this.onCreateSecret}
            >{pubKey ? '更新公钥': '添加公钥'}</Button>
          </div>
        }
      >
        <Descriptions bordered className={styles['descriptions-wrap']}>
          <Descriptions.Item label='公钥' span={3}>
            {pubKey || '-'}
          </Descriptions.Item>
          <Descriptions.Item label='星芽公钥' span={3}>
            {xyPubKey || '-'}
          </Descriptions.Item>
          <Descriptions.Item label='创建时间' span={3}>
            {createTime || '-'}
          </Descriptions.Item>
          <Descriptions.Item label='更新时间' span={3}>
            {updateTime || '-'}
          </Descriptions.Item>
        </Descriptions>
      </Card>
    )
  }
}
export default RSASecret
