import React, { Fragment } from 'react';
import { SearchOutlined, SyncOutlined } from '@ant-design/icons';
import '@ant-design/compatible/assets/index.css';
import { Card, Table, notification, Button, Row, Col, Input, Divider, Select, Badge, Popconfirm, Form } from 'antd';
import * as Format from '@/utils/Format';
import { PageHeaderWrapper } from '@ant-design/pro-layout';
import router from 'umi/router';
import styles from './SonChannelList.less';
import Ellipsis from '@/components/Ellipsis';
import Zmage from 'react-zmage';
import { objFilter } from '@/utils/Help';
import { SettingOutlined, PlusOutlined } from '@ant-design/icons'
import { getChannelPageList } from '@/services/manage'


const { Column } = Table;
const Option = Select.Option;
const FormItem = Form.Item;

class SonChannelList extends React.Component {
  constructor(props) {
    super(props);
    this.formRef = React.createRef()
    this.state = {
      pagination: {
        pageSize: 20,
        current: 1,
        total: 0,
      },
      info: {}
    };
  }

  componentDidMount() {
    const storageParams = sessionStorage.getChannelPageList;
    if (storageParams) {
      const params = JSON.parse(storageParams);
      const pagination = {
        pageSize: params.pageSize,
        current: params.pageIndex,
        total: 0,
      };
      this.setState({ pagination }, () => {
        //获取子渠道列表
        this.getChannelPageList(this.state.pagination.current);
      });
    } else {
      this.getChannelPageList(this.state.pagination.current);
    }
  }

  //获取子渠道列表
  getChannelPageList(pageIndex) {
    const { pagination, loading } = this.state;
    const { channelName, status } = this.formRef.current.getFieldsValue()
    if (loading) return;
    this.setState({ loading: true }, async () => {
      const params = {
        channelName,
        status,
        pageIndex: pageIndex ? pageIndex : pagination.current,
        pageSize: pagination.pageSize,
      };
      objFilter(params); //去除空字段
      const res = await getChannelPageList(params);
      if (res.code === 'OK') {
        const list = res.data.list || [];
        pagination.current = params.pageIndex;
        pagination.total = res.data.total;
        this.setState({ list, loading: false, pagination });
        sessionStorage.getChannelPageList = JSON.stringify(params);
      } else {
        this.setState({ loading: false });
      }
    });
  }

  // 翻页
  handlePage(page) {
    const pageIndex = page.current;
    this.getChannelPageList(pageIndex);
  }

  testLog = () => {
    console.log(this.state)
  }

  //渲染搜索条件
  renderSearch() {
    const { loading } = this.state;
    return (
      <div className={styles.tableListForm}>
        <Form layout="inline" ref={this.formRef}>
          <Row gutter={{ md: 8, lg: 24, xl: 48 }} type="flex" justify="start">
            <Col md={8} sm={24}>
              <FormItem
                label="渠道名称"
                name="channelName"
                rules={[{ required: false, message: '请输入渠道名称' }]}
              >
                <Input placeholder="请输入渠道名称" allowClear />
              </FormItem>
            </Col>

            <Col md={8} sm={24}>
              <FormItem
                label="状态"
                name="status"
                rules={[{ required: false, message: '请选择状态' }]}
              >
                <Select allowClear placeholder="请选择状态">
                  <Option key={1} value={1}>
                    <Badge status="success" text="启用" />
                  </Option>
                  <Option key={0} value={0}>
                    <Badge status="error" text="禁用" />
                  </Option>
                </Select>
              </FormItem>
            </Col>
          </Row>
          <div className={styles.submitButtons}>
            <Button
              type="primary"
              loading={loading}
              icon={<SearchOutlined />}
              onClick={this.getChannelPageList.bind(this, 1)}
            >
              查询
            </Button>
            <Button style={{ marginLeft: 20 }} icon={<SyncOutlined />} onClick={this.resetSearch.bind(this)}>
              重置
            </Button>
          </div>
        </Form>
      </div>
    );
  }

  //重置搜索
  resetSearch() {
    this.formRef.current.resetFields();
    sessionStorage.removeItem('getChannelPageList');
  }

  render() {
    const { list } = this.state;
    return (
      <PageHeaderWrapper
        title={<span onClick={this.testLog.bind(this)}>{this.props.route.name}</span>}
      >
        <Card title="子渠道列表">
          {this.renderSearch()}
          <Table
            rowKey="channelId"
            loading={this.state.loading}
            pagination={this.state.pagination}
            onChange={this.handlePage.bind(this)}
            dataSource={list}
          >
            {/* <Column
              title="头像"
              dataIndex="adminAvatar"
              key="adminAvatar"
              render={adminAvatar => (
                <Zmage
                  className={styles.productPic}
                  src={adminAvatar + '!sq100'}
                  set={[{ src: adminAvatar, alt: '子渠道主图' }]}
                />
              )}
            /> */}
            <Column
              title="ID"
              key="channelId"
              dataIndex="channelId"
            />
            <Column
              title="渠道名称"
              key="channelName"
              dataIndex="channelName"
              render={channelName => (
                <Ellipsis tooltip length={20}>
                  {channelName}
                </Ellipsis>
              )}
            />
            <Column
              title="状态"
              key="status"
              dataIndex="status"
              render={status => (
                <Fragment>
                  {status === 1 && <Badge status="success" text="启用" />}
                  {status === 0 && <Badge status="error" text="禁用" />}
                </Fragment>
              )}
            />
            <Column
              title="今日安装比例百分比"
              key="todayInstallRatio"
              dataIndex="todayInstallRatio"
            />
            <Column
              title="明日安装比例百分比"
              key="tomorrowInstallRatio"
              dataIndex="tomorrowInstallRatio"
            />
            <Column
              title="今日分成比例百分比"
              key="todaySplitRatio"
              dataIndex="todaySplitRatio"
            />
            <Column
              title="明日分成比例百分比"
              key="tomorrowSplitRatio"
              dataIndex="tomorrowSplitRatio"
            />

            {/* <Column
              title="创建时间"
              dataIndex="adminCreateTime"
              key="adminCreateTime"
              render={adminCreateTime => Format.date(adminCreateTime, 'yyyy-MM-dd HH:mm')}
            /> */}
            <Column
              title="操作"
              key="option"
              dataIndex="option"
              render={(option, record, index) => {
                return (
                  <Fragment>
                    <a onClick={() => router.push('/channel/sonChannel/detail?channelId=' + record.channelId)}>详情</a>
                  </Fragment>
                );
              }}
            />
          </Table>
        </Card>
      </PageHeaderWrapper>
    );
  }
}

export default SonChannelList;
