import { Fragment, Component } from "react";
import { Card, Button, Descriptions, Drawer, Form, Input, Col, message, InputNumber } from "antd";
import { SettingOutlined } from '@ant-design/icons';
import { editChanneldivided } from '../services/api';
import numeral from 'numeral'

export default class Channelinstallation extends Component {
  state = {
    visible: false
  }
  onFinish = async (values) => {
    const params = {
      todayInstallRatio: values.todayInstallRatio / 100,
      tomorrowInstallRatio: values.tomorrowInstallRatio / 100,
      todaySplitRatio: values.todaySplitRatio / 100,
      tomorrowSplitRatio: values.tomorrowSplitRatio / 100,
      channelId: this.props.channelId
    }
    const res = await editChanneldivided(params);
    if (res.code == 'OK') {
      message.success('编辑成功');
      this.props.onGetdata();
    }
    else {
      message.error(res.msg);
    }
    this.setState({ visible: false })
  }
  render() {
    const { installData, loading } = this.props;
    const { visible } = this.state;
    const inputData = [
      { label: '今日安装比例百分比', sign: 'todayInstallRatio' },
      { label: '明日安装比例百分比', sign: 'tomorrowInstallRatio' },
      { label: '今日分成比例百分比', sign: 'todaySplitRatio' },
      { label: '明日分成比例百分比', sign: 'tomorrowSplitRatio' },
    ]
    const layout = {
      labelCol: { span: 12 },
      wrapperCol: { span: 12 },
    };
    return (
      <Fragment>
        <Card
          title="渠道分成比例"
          loading={loading}
          extra={
            <Button onClick={() => this.setState({ visible: true })} type="primary" icon={<SettingOutlined />}>编辑</Button>
          }
          style={{ marginBottom: '30px' }}
        >
          <Descriptions
            bordered
            column={{ xxl: 5, xl: 3, lg: 3, md: 3, sm: 2, xs: 1 }}
          >
            {/* <Descriptions.Item label="渠道名称">{installData.channelName}</Descriptions.Item> */}
            <Descriptions.Item label="今日安装比例百分比">{installData.todayInstallRatio ? numeral(installData.todayInstallRatio * 100).format('0') + '%' : '--'}</Descriptions.Item>
            <Descriptions.Item label="明日安装比例百分比">{installData.tomorrowInstallRatio ? numeral(installData.tomorrowInstallRatio * 100).format('0') + '%' : '--'}</Descriptions.Item>
            <Descriptions.Item label="今日分成比例百分比">{installData.todaySplitRatio ? numeral(installData.todaySplitRatio * 100).format('0') + '%' : '--'}</Descriptions.Item>
            <Descriptions.Item label="明日分成比例百分比">{installData.tomorrowSplitRatio ? numeral(installData.tomorrowSplitRatio * 100).format('0') + '%' : '--'}</Descriptions.Item>
          </Descriptions>
        </Card>
        <Drawer
          title="设置渠道分成比例"
          placement="right"
          closable={false}
          onClose={() => this.setState({ visible: false })}
          visible={visible}
          width='400px'
          destroyOnClose={true}
        >
          <Form
            name="customized_form_controls"
            layout='horizontal'
            onFinish={this.onFinish}
            initialValues={{
              todayInstallRatio: installData.todayInstallRatio ? installData.todayInstallRatio * 100 : undefined,
              tomorrowInstallRatio: installData.tomorrowInstallRatio ? installData.tomorrowInstallRatio * 100 : undefined,
              todaySplitRatio: installData.todaySplitRatio ? installData.todaySplitRatio * 100 : undefined,
              tomorrowSplitRatio: installData.tomorrowSplitRatio ? installData.tomorrowSplitRatio * 100 : undefined
            }}
            {...layout}
          >
            {
              inputData.map((item, index) => {
                return (
                  <Form.Item
                    key={index}
                    name={item.sign}
                    label={item.label}
                    rules={[{ required: true, message: '请输入比例数值' }]}
                  >
                    <InputNumber
                      style={{
                        width: '100%',
                      }}
                      formatter={value => `${value}%`}
                      max={100}
                      min={0}
                      step={1}
                    />
                  </Form.Item>
                )
              })
            }
            <Form.Item style={{ textAlign: 'center' }}>
              <Button type="primary" htmlType="submit">确认编辑</Button>
            </Form.Item>
          </Form>
        </Drawer>
      </Fragment >
    )
  }
}