/**
 * 
 * 筛选条件
 */
import React, { Component } from 'react'
import styles from './NotifyRecordsFilters.less'
import { Select, Input, Button, DatePicker } from 'antd'
import moment from 'moment'
import { SearchOutlined } from '@ant-design/icons'
import { redEvelopResultArray } from '../common'

const Option = Select.Option
const RangePicker = DatePicker.RangePicker
const _style = {
  width: '100%'
}
class NotifyRecordsFilters extends Component {
  // 选择
  onSelectChange = name => key => {
    const { onChange } = this.props
    onChange && onChange(name, key)
  }
  // 输入
  onInputChange = name => e => {
    const { value } = e.target
    const { onChange } = this.props
    onChange && onChange(name, value)
  }
  // 时间筛选
  onDateChange = (moments) => {
    let _startTime
    let _endTime
    if (moments && moments.length) {
      _startTime = moments[0].startOf('date').valueOf()
      _endTime = moments[1].endOf('date').valueOf()
    }
    const { onChange } = this.props
    onChange && onChange([{ name: 'startTime', value: _startTime }, { name: 'endTime', value: _endTime }])
  }
  render () {
    const { onSearch, isSuccess, tradeId, startTime, endTime } = this.props
    return (
      <div className={styles['wrap']}>
        <div className={styles['filter-item']}>
          <h4 className={styles['filter-label']}>处理结果:</h4>
          <Select
            style={_style}
            placeholder='请选择处理结果'
            value={isSuccess}
            onChange={this.onSelectChange('isSuccess')}
            allowClear={false}
          >
            {
              redEvelopResultArray && redEvelopResultArray.map((item) => (
                <Option key={item.key}>{item.value}</Option>
              ))
            }
          </Select>
        </div>
        <div className={styles['filter-item']}>
          <h4 className={styles['filter-label']}>红包记录ID:</h4>
          <Input 
            placeholder='请输入红包记录ID'
            style={_style}
            value={tradeId}
            onChange={this.onInputChange('tradeId')}
            allowClear
          />
        </div>
        
        <div className={`${styles['filter-item']} ${styles['filter-item-time']}`}>
          <h4 className={styles['filter-label']}>时间:</h4>
          <RangePicker 
            style={_style}
            onChange={this.onDateChange}
            value={startTime ? [moment(startTime), moment(endTime)] : undefined}
          />
        </div>
        <div>
          <Button
            icon={<SearchOutlined />}
            onClick={onSearch}
            type='primary'
          >搜索</Button>
        </div>
      </div>
    )
  }
}
export default NotifyRecordsFilters
