import LineWrap from './LineWrap'
import { Card, Table, Descriptions, Button } from 'antd'
import { EditOutlined, PlusOutlined } from '@ant-design/icons'
import styles from './RedEnvelop.less'
const _cardStyle = {
  marginBottom: 10
}
const Column = Table.Column
export default ({
  goRecords,
  apiName, apiDesc, apiPath, commonParams, contentType, curlExample, responseExample,
  failCodes, method, returnParams, triggerConditions, verificationInstructions,
  notifyParams, hostUrl, onEdit, createTime, updateTime
}) => (
  <div>
    <Card 
      style={_cardStyle} 
      title='我的回调配置'
      extra={
        <div hidden>
          <Button
            type='primary'
            icon={<PlusOutlined />}
            onClick={goRecords}
          >回调记录</Button>
        </div>
      }
    >
      <Descriptions bordered>
        <Descriptions.Item label='回调地址' span={3}>
          <div className={styles['host-url-wrap']}>
            <span>{hostUrl || '未配置'}</span>
            <Button
              type="primary"
              icon={<EditOutlined />}
              onClick={onEdit}
              ghost
              size='small'
            />
          </div>
        </Descriptions.Item>
        {
          !!hostUrl &&
          <Descriptions.Item label='更新时间' span={3}>
            {createTime}
          </Descriptions.Item>
        }
        {
          !!hostUrl &&
          <Descriptions.Item label='创建时间' span={3}>
            {updateTime}
          </Descriptions.Item>
        }
      </Descriptions>
    </Card>
    
    <Card title='详细描述'>
      <LineWrap label='名称'>{apiName}</LineWrap>
      <LineWrap label='描述'>{apiDesc}</LineWrap>
      <LineWrap label='接口路径'>{apiPath}</LineWrap>
      <LineWrap label='请求方式'>{method}</LineWrap>
      <LineWrap label='contentType'>{contentType}</LineWrap>
      <LineWrap label='公共参数'>
        <Table
          dataSource={commonParams}
          pagination={false}
          rowKey={(record, i) => i}
          bordered
        >
          <Column 
            title='参数'
            key='param'
            dataIndex='param'
          />
          <Column 
            title='名称'
            key='name'
            dataIndex='name'
          />
          <Column 
            title='类型'
            key='type'
            dataIndex='type'
          />
          <Column 
            title='长度'
            key='maxLength'
            dataIndex='maxLength'
          />
          <Column 
            title='是否必须'
            key='required'
            dataIndex='required'
            render={(required) => required ? '是' : '否'}
          />
          <Column 
            title='描述'
            key='desc'
            dataIndex='desc'
          />
          <Column 
            title='示例'
            key='example'
            dataIndex='example'
          />
        </Table>
      </LineWrap>
      {
        !!notifyParams && 
        <LineWrap label='异步通知参数'>
          <Table
            dataSource={notifyParams}
            pagination={false}
            rowKey={(record, i) => i}
            bordered
          >
            <Column 
              title='参数'
              key='param'
              dataIndex='param'
            />
            <Column 
              title='名称'
              key='name'
              dataIndex='name'
            />
            <Column 
              title='类型'
              key='type'
              dataIndex='type'
            />
            <Column 
              title='长度'
              key='maxLength'
              dataIndex='maxLength'
            />
            <Column 
              title='是否必须'
              key='required'
              dataIndex='required'
              render={(required) => required ? '是' : '否'}
            />
            <Column 
              title='描述'
              key='desc'
              dataIndex='desc'
            />
            <Column 
              title='示例'
              key='example'
              dataIndex='example'
            />
          </Table>
        </LineWrap>
      }
        <LineWrap label='返回参数'>
          <Table
            dataSource={returnParams}
            pagination={false}
            rowKey={(record, i) => i}
            bordered
          >
            <Column 
              title='参数'
              key='param'
              dataIndex='param'
            />
            <Column 
              title='名称'
              key='name'
              dataIndex='name'
            />
            <Column 
              title='类型'
              key='type'
              dataIndex='type'
            />
            <Column 
              title='长度'
              key='maxLength'
              dataIndex='maxLength'
            />
            <Column 
              title='是否必须'
              key='required'
              dataIndex='required'
              render={(required) => required ? '是' : '否'}
            />
            <Column 
              title='描述'
              key='desc'
              dataIndex='desc'
            />
            <Column 
              title='示例'
              key='example'
              dataIndex='example'
            />
          </Table>
        </LineWrap>
        <LineWrap label='触发条件'>
          {
            triggerConditions && triggerConditions.map((item, i) => (
              <div key={i}>{item}</div>
            ))
          }
        </LineWrap>
        <LineWrap label='正常响应示例'>
          {responseExample}
        </LineWrap>
        <LineWrap label='返回结果的验签'>
          {verificationInstructions && verificationInstructions.map((item, i) => (
            <div key={i}>{item}</div>
          ))}
        </LineWrap>
        <LineWrap label='失败码说明'>
          {failCodes && failCodes.map((item, i) => (
            <div key={i}>{item}</div>
          ))}
        </LineWrap>
        <LineWrap label='CURL请求示例'>
          {curlExample}
        </LineWrap>
        
    </Card>
  </div>
)
