/**
 * 
 * 用户详情
 */
import React, { Component } from 'react'
import { LeftOutlined, ManOutlined, WomanOutlined } from '@ant-design/icons';
import { Button, Descriptions, Card, Table, Tag, Modal, Input, notification } from 'antd';
import ZImage from 'react-zmage'
import { getDate, showSuccess } from '@/utils/base'
import { PageHeaderWrapper } from '@ant-design/pro-layout'
import router from 'umi/router'
import { getUserDetail, unbindAlipay, setUserName } from './api'
// import { SingChatRecord } from '@/components/PageContent'

const fmt = 'yyyy-MM-dd hh:mm'

const cardStyle = {
  marginBottom: 10
}
const tagStyle = {
  minWidth: 100,
  textAlign: 'center',
  fontSize: 14
}
const Column = Table.Column
class UserDetails extends Component {
  constructor(props) {
    super(props)
    this.state = {
      loading: false,
      // 分页
      pagination: {
        current: 1
      },
      tableLoading: false,
      userId: props.location.query.userId,
      userInfo: {}
    }
  }

  componentDidMount() {
    // 获取用户详情
    this.getDetails()
  }

  componentWillUnmount() {
    if (this.timer) {
      clearTimeout(this.timer)
    }
  }

  getDetails = async () => {
    const { userId } = this.state
    const _state = {
      loading: false
    }
    try {
      this.setState({ loading: true })
      const { data, code } = await getUserDetail({ userId })
      const {
        userName, userAvatar, userNo, userSex, userPhone, userEmail, userStatus,
        isAnchor, userCreateTime, userAddress, userAge, wealthLevel, charmLevel,
        charmValue, wealthValue, alipayAccount
      } = data

      _state.userInfo = data

      // 用户昵称
      _state.userName = userName
      // 用户头像
      _state.userAvatar = userAvatar
      // 星芽号
      _state.userNo = userNo
      // 用户id
      _state.userId = userId
      // 性别
      _state.userSex = userSex
      // 手机号码
      _state.userPhone = userPhone
      // 邮箱
      _state.userEmail = userEmail
      // 是否主播
      _state.isAnchor = isAnchor
      // 注册时间
      _state.userCreateTime = userCreateTime
      // 用户状态
      _state.userStatus = userStatus
      // 用户地址
      _state.userAddress = userAddress
      // 用户年龄
      _state.userAge = userAge
      // 财富等级
      _state.wealthLevel = wealthLevel
      // 魅力等级
      _state.charmLevel = charmLevel
      // 财富值
      _state.charmValue = charmValue
      // 魅力值
      _state.wealthValue = wealthValue
      // 支付宝绑定
      _state.alipayAccount = alipayAccount
    } catch (e) {
      console.log(e)
    }

    this.setState(_state)
  }

  // 解绑
  onUnBind = (e) => {
    e.preventDefault()
    const { userName, userId } = this.state
    Modal.confirm({
      title: '解绑提示',
      content: `确定对${userName}执行支付宝解绑操作吗?`,
      okText: '确定',
      cancelText: '取消',
      onOk: () => {

        return unbindAlipay({ userId })
          .then(() => {
            showSuccess('成功解绑支付宝')
            this.getDetails()
          })
      }
    })
  }

  //编辑昵称
  setUserName = () => {
    const { userInfo, newUserName } = this.state
    this.setState({ setNameLoading: true }, async () => {
      const res = await setUserName({ userName: newUserName, userId: userInfo.userId })
      if (res.success) {
        this.timer = setTimeout(() => {
          notification.success({
            message: '昵称编辑成功'
          })
          this.setState({ setNameLoading: false, setNameModal: false }, () => {
            this.getDetails()
          })
        }, 1000);
      } else {
        this.setState({ setNameLoading: false })
      }
    })
  }

  render() {
    const {
      loading, userName, userAvatar, userNo, userId, userSex, userPhone, userEmail, userStatus,
      isAnchor, userCreateTime, userAddress, userAge, wealthLevel, charmLevel,
      wealthValue, charmValue, alipayAccount,
      tableLoading, list, pagination, userInfo
    } = this.state

    const { total, current, pageSize } = pagination
    const hidePagination = current === 1 && pageSize >= total
    return (
      <PageHeaderWrapper
        title='用户详情'
        extra={
          <div>
            <Button
              onClick={router.goBack}
              type='default'
              icon={<LeftOutlined />}
            >返回</Button>
          </div>
        }
      >
        <Card title='基本信息' style={cardStyle} loading={loading}>
          <Descriptions bordered>
            <Descriptions.Item label='头像'>
              {userAvatar ? <ZImage src={userAvatar} style={{ width: 80 }} /> : '-'}
            </Descriptions.Item>
            <Descriptions.Item label='颜值封面'>
              {userInfo.userCover ? <ZImage src={userInfo.userCover} style={{ width: 80 }} /> : '-'}
            </Descriptions.Item>
            <Descriptions.Item label='昵称'>
              {userName}
            </Descriptions.Item>
            <Descriptions.Item label='性别'>
              {
                userSex === 1
                  ? <ManOutlined style={{ color: '#1890ff' }} />
                  : userSex === 2
                    ? <WomanOutlined style={{ color: '#eb2f96' }} />
                    : '-'
              }
            </Descriptions.Item>
            <Descriptions.Item label='用户状态'>
              {userStatus === 1 ? '正常' : '已封禁'}
            </Descriptions.Item>
            <Descriptions.Item label='财富等级(值)'>
              {wealthLevel}({wealthValue})
            </Descriptions.Item>
            <Descriptions.Item label='魅力等级(值)'>
              {charmLevel}({charmValue})
            </Descriptions.Item>

            <Descriptions.Item label='用户地址'>
              {userAddress || '-'}
            </Descriptions.Item>
            <Descriptions.Item label='年龄'>
              {userAge || '-'}
            </Descriptions.Item>
            <Descriptions.Item label='星芽号'>
              {userNo}
            </Descriptions.Item>
            <Descriptions.Item label='用户id'>
              {userId}
            </Descriptions.Item>
            <Descriptions.Item label='手机号'>
              {userPhone || '-'}
            </Descriptions.Item>
            <Descriptions.Item label='邮箱'>
              {userEmail || '-'}
            </Descriptions.Item>
            <Descriptions.Item label='是否主播'>
              {isAnchor === 1 ? '是' : '否'}
            </Descriptions.Item>

            <Descriptions.Item label='注册时间'>
              {userCreateTime ? getDate(+userCreateTime, fmt) : '-'}
            </Descriptions.Item>
            <Descriptions.Item label='支付宝'>
              {
                !!alipayAccount
                  ? <a href="#" onClick={this.onUnBind}>解绑</a>
                  : '未绑定'
              }
            </Descriptions.Item>

            <Descriptions.Item label='所属渠道'>
              {userInfo.channelId && `${userInfo.channelName}(${userInfo.channelId})`}
            </Descriptions.Item>
            <Descriptions.Item label='是否机器人'>
              {userInfo.userIsRobot === 1 ? '是' : '否'}
            </Descriptions.Item>
            <Descriptions.Item label='是否市场审核人'>
              {userInfo.userIsMarketAuditor === 1 ? '是' : '否'}
            </Descriptions.Item>
            <Descriptions.Item label='邀请人'>
              {userInfo.inviterUserId && `${userInfo.inviterUserName}(${userInfo.inviterUserId})`}
            </Descriptions.Item>

          </Descriptions>
        </Card>
        {/* <SingChatRecord
          userId={userId}
        /> */}
        <Modal
          title="设置昵称"
          visible={this.state.setNameModal}
          onCancel={() => this.setState({ setNameModal: false })}
          okText="确定编辑"
          onOk={this.setUserName}
          okButtonProps={{ loading: this.state.setNameLoading }}
        >
          <Input placeholder="请输入用户昵称" value={this.state.newUserName} onChange={e => this.setState({ newUserName: e.target.value })} />
        </Modal>
      </PageHeaderWrapper>
    );
  }
}
export default UserDetails
