/**
 * 
 * 用户列表
 */
import React, { Component } from 'react'
import { PageHeaderWrapper } from '@ant-design/pro-layout'
import router from 'umi/router'
import { ManOutlined, WomanOutlined } from '@ant-design/icons';
import { Card, Table } from 'antd';
import styles from './UserList.less'
// 引入接口
import { getUserList } from './api'
// 引入模块公用组件
import { Filters } from './components'
// 引入公用函数
import { getDate } from '@/utils/base'
// 引入模块公用函数
import { reportStatus, getStatusStr } from './common'
// 引入的图片展示组件
import ZImage from 'react-zmage'

// table 
const Column = Table.Column
const storeName = 'userListStore'

class UserList extends Component {
  constructor(props) {
    super(props)
    this.state = {
      // 加载列表 loading
      loading: false,
      // 列表数据
      list: [],
      // 姓名
      userName: '',
      // 分页
      pagination: {
        current: 1
      }
    }
  }
  componentDidMount() {
    const _state = {}
    if (this.props.location.query.useStore) {
      // 使用本地数据
      const jsonString = sessionStorage[storeName]
      if (jsonString) {
        const json = JSON.parse(jsonString)
        Object.assign(_state, json)
      }
      router.replace({
        pathname: this.props.location.pathname
      })
      sessionStorage.removeItem(storeName)
    }

    this.setState(_state, this.getList)
  }

  // 获取列表
  getList = async () => {
    const _state = {
      loading: false
    }
    try {
      const {
        userName, userNo, userPhone, pagination, isAnchor, sortType,
        userStatus, niceNo, startTime, endTime
      } = this.state
      // 页码，每页条数
      const _params = {
        pageNum: pagination.current || 1,
        pageSize: 10,
      }
      // 名字
      if (userName) {
        // _params.pageNum = 1
        _params.userName = userName
      }

      // 靓号
      if (niceNo) {
        _params.niceNo = niceNo
      }

      // 星芽号
      if (userNo) {
        _params.userNo = userNo
      }

      // 手机号
      if (userPhone) {
        _params.userPhone = userPhone
      }

      // 是否主播
      if (isAnchor && isAnchor !== 'all') {
        _params.isAnchor = isAnchor
      }

      // 排序方式
      if (sortType) {
        _params.sortType = sortType
      }

      // 用户状态
      if (userStatus !== 'all' && userStatus) {
        _params.userStatus = userStatus
      }

      // 时间
      if (startTime) {
        _params.startTime = startTime
        _params.endTime = endTime
      }

      this.setState({ loading: true })
      const { data, code } = await getUserList(_params)
      if (code === 'OK' && data) {
        const { list, total, pageIndex, pageSize } = data
        _state.list = list
        _state.pagination = {
          current: pageIndex,
          total: total,
          pageSize: pageSize
        }
      }
    } catch (e) {
      console.log(e)
    }
    this.setState(_state)
  }

  // 子组建内容变化
  onChange = (name, value) => {
    if (Array.isArray(name)) {
      let _state = {}
      name.map((item) => {
        _state[item.name] = item.value
      })
      this.setState(_state)
      return
    }
    this.setState({ [name]: value })
  }
  // 搜索
  onSearch = () => {
    const { pagination } = this.state
    pagination.current = 1
    this.setState({ pagination }, this.getList)
  }

  onPageChange = (pagination) => {
    this.setState({ pagination }, this.getList)
  }

  // 详情
  showDetails = (record) => {
    router.push({
      pathname: '/customer/list/details',
      query: {
        userId: record.userId
      }
    })
  }

  render() {
    const {
      loading, list, userName, userPhone, niceNo, userStatus, pagination,
      startTime, endTime, userNo, sortType, isAnchor
    } = this.state
    const { total, current, pageSize } = pagination
    const hidePagination = current === 1 && pageSize >= total
    return (
      <PageHeaderWrapper
        title='用户列表'
      >
        <Card>
          <Filters
            status={reportStatus}
            onChange={this.onChange}
            userName={userName}
            userNo={userNo}
            niceNo={niceNo}
            sortType={sortType}
            userStatus={userStatus}
            userPhone={userPhone}
            isAnchor={isAnchor}
            onSearch={this.onSearch}
            startTime={startTime}
            endTime={endTime}
          />
          <Table
            loading={loading}
            dataSource={list}
            rowKey='userNo'
            onChange={this.onPageChange}
            bordered
            pagination={hidePagination ? false : pagination}
          >
            <Column
              title='头像'
              key='userAvatar'
              dataIndex='userAvatar'
              render={(text, { userAvatar }) => (
                userAvatar
                  ? <ZImage src={userAvatar} style={{ width: 60 }} />
                  : '-'
              )}
            />
            <Column
              title='星芽号'
              key='userNo'
              dataIndex='userNo'
            />
            <Column
              title='昵称'
              key='userName'
              dataIndex='userName'
            />
            <Column
              title='性别'
              key='userSex'
              dataIndex='userSex'
              render={userSex => (
                userSex === 1
                  ? <ManOutlined style={{ color: '#1890ff' }} />
                  : userSex === 2
                    ? <WomanOutlined style={{ color: '#eb2f96' }} />
                    : '-'
              )}
            />
            <Column
              title='手机号'
              key='userPhone'
              dataIndex='userPhone'
              render={text => text || '-'}
            />
            <Column
              title='是否主播'
              key='isAnchor'
              dataIndex='isAnchor'
              render={(text, { isAnchor }) => (
                <div>{isAnchor === 1 ? '是' : '否'}</div>
              )}
            />
            <Column
              title='财富等级'
              key='wealthLevel'
              dataIndex='wealthLevel'
            />
            <Column
              title='魅力等级'
              key='charmLevel'
              dataIndex='charmLevel'
            />
            <Column
              title='注册时间'
              key='userCreateTime'
              dataIndex='userCreateTime'
              render={(text, { userCreateTime }) => (
                <div>
                  {userCreateTime && userCreateTime !== '0'
                    ? getDate(+userCreateTime, 'yyyy-MM-dd hh:mm')
                    : '-'
                  }
                </div>
              )}
            />
            <Column
              title='状态'
              key='userStatus'
              dataIndex='userStatus'
              render={(text, { userStatus }) => (
                <div>{getStatusStr(userStatus)}</div>
              )}
            />
            <Column
              title='操作'
              key='actions'
              dataIndex='actions'
              align='center'
              width={120}
              render={(text, record) => (
                <div className={styles['list-actions']}>
                  <a href="#" onClick={e => {
                    e.preventDefault()
                    this.showDetails(record)
                  }}>详情</a>
                </div>
              )}
            />
          </Table>
        </Card>
      </PageHeaderWrapper>
    );
  }
}
export default UserList
