{/* <AddMount
  userInfo={this.state.userInfo}
  drawerProps={{
    width: 600,
    title: type === 'add' ? '添加用户' : '编辑用户',
    visible: this.state.addUserModal,
    onClose: () => this.setState({ addUserModal: false }),
  }}
  refresh={this.afterAddUser.bind(this)}
  type={this.state.actionType}
/> */}

import React, { Fragment } from 'react';
import { Form } from '@ant-design/compatible';
import '@ant-design/compatible/assets/index.css';
import {
  Button,
  Input,
  notification,
  Drawer,
  message,
  Select,
  InputNumber,
  Tag,
  Radio,
} from 'antd';
import { createUser, getUserAvatarUploadConfig, editUser, getUserCoverUploadConfig } from '../api';
import { objFilter } from '@/utils/Help';
import MyUpload from '@/components/Custom/MyUpload';
import { ChannelSelect } from '@/pages/Chanel/utils';
import { SelectUser } from '@/components/Modals';
import RedStar from '@/components/Custom/RedStar';
import { ClientType } from '@/utils/base'

const FormItem = Form.Item;
const Option = Select.Option;
const formItemLayout = {
  labelCol: {
    xs: {
      span: 24,
    },
    sm: {
      span: 7,
    },
  },
  wrapperCol: {
    xs: {
      span: 24,
    },
    sm: {
      span: 12,
    },
    md: {
      span: 10,
    },
  },
};

@Form.create()
class AddCustomer extends React.Component {
  constructor(props) {
    super(props);
    this.state = {
      info: {},
      channelInfo: {},
      inviterInfo: {},    //邀请人
    };
  }

  componentDidMount() {
    if (this.props.type === 'update') {
      const userInfo = this.props.userInfo;
      this.props.form.setFieldsValue({
        userPhone: userInfo.userPhone,
        //userIsMarketAuditor: userInfo.userIsMarketAuditor,
        //userIsRobot: userInfo.userIsRobot,
        nickName: userInfo.userName,
        sex: userInfo.userSex
      });
      const channelInfo = {
        channelId: userInfo.channelId,
        channelName: userInfo.channelName
      }
      const inviterInfo = {
        inviterUserId: userInfo.inviterUserId,
        inviterUserName: userInfo.inviterUserName
      }
      this.setState({ channelInfo, inviterInfo })
    }
  }

  componentDidUpdate(prevProps, prevState, snapshot) {
    if (this.state.uploadRef && !prevState.uploadRef && this.props.type === 'update') {
      const { userInfo } = this.props;
      if (userInfo.userAvatar) {
        this.state.uploadRef.setState({
          fileList: [
            {
              uid: Date.now(),
              status: 'done',
              url: userInfo.userAvatar,
              name: '用户图片',
            },
          ],
        });
      }
    }
    if (this.state.uploadRef2 && !prevState.uploadRef2 && this.props.type === 'update') {
      const { userInfo } = this.props;
      if (userInfo.userCover) {
        this.state.uploadRef2.setState({
          fileList: [
            {
              uid: Date.now(),
              status: 'done',
              url: userInfo.userCover,
              name: '颜值封面',
            },
          ],
        });
      }
    }
  }

  componentWillUnmount() {
    if (this.timer) {
      clearTimeout(this.timer);
    }
  }

  //测试
  testLog() {
    console.log(this.state);
  }

  //  提交
  handleSubmit() {
    const { form } = this.props;
    form.validateFieldsAndScroll((err, values) => {
      if (!err) {
        this.createUser(values);
      }
    });
  }

  //添加用户
  async createUser(values) {
    const { submitLoading, uploadRef, channelInfo, inviterInfo, uploadRef2 } = this.state;
    if (!channelInfo.channelName) {
      message.error('请选择渠道')
      return
    }

    const { type, userInfo } = this.props;
    const params = {
      ...values,
      headImgUrl: uploadRef.state.fileList.length === 0 ? '' : uploadRef.state.fileList[0].url,
      userCover: uploadRef2.state.fileList.length === 0 ? '' : uploadRef2.state.fileList[0].url,
      userId: type === 'add' ? '' : userInfo.userId,
      channelId: channelInfo.channelId,
      inviterUserId: inviterInfo.userId,
      deviceId: 'manager'
    };
    if (params.inviterUserId === userInfo.userId && type === 'update') {
      message.error('邀请人不能为自己')
      return
    }
    if (type === 'update') {
      params.userName = params.nickName
      delete params.nickName
      params.userAvatar = params.headImgUrl
      delete params.headImgUrl
      params.userSex = params.sex
      delete params.sex
      delete params.deviceId
    }
    objFilter(params);
    console.log(`提交: `, params);
    if (submitLoading) return;
    this.setState({ submitLoading: true });
    const res = type === 'add' ? await createUser(params) : await editUser(params);
    if (res.msg === 'err') return;
    if (res.code === 'OK') {
      notification['success']({
        message: type === 'add' ? '用户添加成功' : '用户编辑成功',
      });
      this.setState({ submitLoading: false }, () => {
        this.props.form.resetFields();
        uploadRef.setState({ fileList: [] });
        uploadRef2.setState({ fileList: [] });
        this.props.refresh();
      });
    } else {
      this.setState({ submitLoading: false });
    }
  }

  saveUploadRef(uploadRef) {
    this.setState({ uploadRef });
  }

  saveUploadRef2(uploadRef2) {
    this.setState({ uploadRef2 });
  }

  // 选择用户
  onSelectUser = () => {
    SelectUser({
      type: 'radio',
      onOk: (choosen) => {
        console.log(choosen[0])
        this.setState({ inviterInfo: choosen[0] })
      }
    })
  }

  render() {
    const { loading, channelInfo, inviterInfo } = this.state;
    const { getFieldDecorator } = this.props.form;
    const { drawerProps, type } = this.props;
    return (
      <Drawer {...drawerProps}>
        <Form>
          <FormItem
            label={<span onClick={() => console.log(this.state)}>用户名称</span>}
            {...formItemLayout}
          >
            {getFieldDecorator('nickName', {
              rules: [{ required: true, message: '请输入用户名称' }],
            })(<Input placeholder="请输入用户名称" />)}
          </FormItem>

          <FormItem
            label="手机号码"
            {...formItemLayout}
          >
            {getFieldDecorator('userPhone', {
              rules: [{ required: true, message: '手机号码' }],
            })(
              <InputNumber style={{ width: '100%' }} placeholder="手机号码" />
            )}
          </FormItem>

          <FormItem
            label={<RedStar title="所属渠道" />}
            {...formItemLayout}
          >
            {channelInfo.channelId ? (
              <Tag closable onClose={() => this.setState({ channelInfo: {} })}>{channelInfo.channelName}</Tag>
            ) : (
                <Button onClick={() => this.setState({ channelModal: true })}>选择渠道</Button>
              )}
          </FormItem>

          {type === 'add' && (
            <Fragment>
              <FormItem
                label="邀请人"
                {...formItemLayout}
              >
                {inviterInfo.userId ? (
                  <Tag closable onClose={() => this.setState({ inviterInfo: {} })}>{inviterInfo.userName}</Tag>
                ) : (
                    <Button onClick={this.onSelectUser}>选择邀请人</Button>
                  )}
              </FormItem>

              <FormItem label="是否市场审核人" {...formItemLayout}>
                {getFieldDecorator('userIsMarketAuditor', {
                  rules: [{ required: false, message: '是否市场审核人' }],
                })(
                  <Radio.Group>
                    <Radio value={1}>是</Radio>
                    <Radio value={0} style={{ marginLeft: 20 }}>
                      否
                </Radio>
                  </Radio.Group>,
                )}
              </FormItem>

              <FormItem label="是否机器人" {...formItemLayout}>
                {getFieldDecorator('userIsRobot', {
                  rules: [{ required: false, message: '是否机器人' }],
                })(
                  <Radio.Group>
                    <Radio value={1}>是</Radio>
                    <Radio value={0} style={{ marginLeft: 20 }}>
                      否
                </Radio>
                  </Radio.Group>,
                )}
              </FormItem>
            </Fragment>
          )}

          <FormItem label="性别" {...formItemLayout}>
            {getFieldDecorator('sex', {
              rules: [{ required: false, message: '性别' }],
            })(
              <Radio.Group>
                <Radio value={1}>男</Radio>
                <Radio value={2} style={{ marginLeft: 20 }}>
                  女
                </Radio>
              </Radio.Group>,
            )}
          </FormItem>

          <FormItem label="用户头像" {...formItemLayout}>
            <div style={{ height: 120 }}>
              <MyUpload
                saveData={this.saveUploadRef.bind(this)}
                requestUrl={getUserAvatarUploadConfig}
              />
            </div>
            {/* <Alert message="建议尺寸为750px * 750px" type="info" showIcon /> */}
          </FormItem>

          <FormItem label="颜值封面" {...formItemLayout} className={type === 'add' ? 'hidden' : ''}>
            <div style={{ height: 120 }}>
              <MyUpload
                saveData={this.saveUploadRef2.bind(this)}
                requestUrl={getUserCoverUploadConfig}
              />
            </div>
            {/* <Alert message="建议尺寸为750px * 750px" type="info" showIcon /> */}
          </FormItem>

          {type === 'add' && (
            <Fragment>
              <FormItem
                label="客户端"
                {...formItemLayout}
              >
                {getFieldDecorator('clientType', {
                  rules: [{ required: true, message: '客户端' }],
                })(
                  <Select allowClear placeholder="客户端" allowClear>
                    {Object.keys(ClientType).map(key => {
                      return (
                        <Option key={key} value={key}>{ClientType[key]}</Option>
                      )
                    })}
                  </Select>
                )}
              </FormItem>

              <FormItem
                label="注册类型"
                {...formItemLayout}
              >
                {getFieldDecorator('registerType', {
                  rules: [{ required: false, message: '注册类型' }],
                })(
                  <Select allowClear placeholder="注册类型" allowClear>
                    <Option key={101} value={101}>手机注册</Option>
                    <Option key={102} value={102}>QQ注册</Option>
                    <Option key={103} value={103}>微信注册</Option>
                    <Option key={104} value={104}>微博注册</Option>
                    <Option key={105} value={105}>手机号一键登录</Option>
                    <Option key={106} value={106}>华为注册</Option>
                  </Select>
                )}
              </FormItem>
            </Fragment>
          )}

          <div
            style={{
              position: 'absolute',
              bottom: 0,
              width: '100%',
              borderTop: '1px solid #e8e8e8',
              padding: '10px 16px',
              textAlign: 'right',
              left: 0,
              background: '#fff',
              borderRadius: '0 0 4px 4px',
            }}
          >
            <Button
              style={{
                marginRight: 8,
              }}
              onClick={drawerProps.onClose}
            >
              取消
            </Button>
            <Button onClick={this.handleSubmit.bind(this)} loading={loading} type="primary">
              {type === 'add' ? '确定添加' : '确定编辑'}
            </Button>
          </div>
        </Form>
        {/* 渠道选择 */}
        <ChannelSelect
          drawerProps={{
            title: '选择渠道',
            width: 900,
            visible: !!this.state.channelModal,
            onClose: () => this.setState({ channelModal: false })
          }}
          onSelect={channelInfo => this.setState({ channelInfo, channelModal: false })}
        />
      </Drawer>
    );
  }
}

export default AddCustomer;

AddCustomer.defaultProps = {
  userInfo: {}
}

