/**
 * 
 * 用户列表 筛选条件
 */
import React, { Component } from 'react'
import styles from './Filters.less'
import { SearchOutlined } from '@ant-design/icons';
import { Select, Input, Button, DatePicker, InputNumber } from 'antd'
import moment from 'moment'
import { regIntNumber } from '@/utils/base'
import { sortMethods, isAnchorList } from '../common'

const Option = Select.Option
const RangePicker = DatePicker.RangePicker
const _style = {
  width: '100%'
}
class Filters extends Component {
  onUserName = (e) => {
    const { value } = e.target
    const { onChange } = this.props
    onChange && onChange('userName', value)
  }
  onUserPhone = (e) => {
    const { value } = e.target
    const { onChange } = this.props
    onChange && onChange('userPhone', value)
  }

  // 星芽号
  onUserNo = (e) => {
    const { value } = e.target
    if (value && !regIntNumber.test(value)) {
      return
    }
    const { onChange } = this.props
    onChange && onChange('userNo', value)
  }

  // 靓号
  onNiceNo = (e) => {
    const { value } = e.target
    if (value && !regIntNumber.test(value)) {
      return
    }
    const { onChange } = this.props
    onChange && onChange('niceNo', value)
  }

  // 是否主播
  onIsAnchor = (key) => {
    const { onChange } = this.props
    onChange && onChange('isAnchor', key)
  }

  // 状态改变
  onStatusChange = key => {
    const { onChange } = this.props
    onChange && onChange('userStatus', key)
  }

  // 排序方式
  onSortChange = (key) => {
    const { onChange } = this.props
    onChange && onChange('sortType', key)
  }

  // 时间筛选
  onDateChange = (moments) => {
    let _startTime
    let _endTime
    if (moments && moments.length) {
      _startTime = moments[0].valueOf()
      _endTime = moments[1].valueOf()
    }
    const { onChange } = this.props
    onChange && onChange([{ name: 'startTime', value: _startTime }, { name: 'endTime', value: _endTime }])
  }
  render () {
    const { 
      status, onSearch, userName, userStatus, userPhone, startTime, endTime,
      userNo, sortType, niceNo, isAnchor
    } = this.props
    return (
      <div className={styles['wrap']}>
        <div className={styles['filter-item']}>
          <h4 className={styles['filter-label']}>用户昵称:</h4>
          <Input 
            placeholder='请输入用户昵称'
            style={_style}
            value={userName}
            onChange={this.onUserName}
            allowClear
          />
        </div>
        <div className={styles['filter-item']}>
          <h4 className={styles['filter-label']}>星芽号:</h4>
          <Input 
            placeholder='请输入星芽号(数值)'
            style={_style}
            value={userNo}
            onChange={this.onUserNo}
            allowClear
          />
        </div>
        
        <div className={styles['filter-item']}>
          <h4 className={styles['filter-label']}>手机号:</h4>
          <Input
            placeholder='请输入手机号'
            style={_style}
            value={userPhone}
            onChange={this.onUserPhone}
            allowClear
          />
        </div>
        <div className={styles['filter-item']}>
          <h4 className={styles['filter-label']}>靓号:</h4>
          <Input
            placeholder='请输入靓号'
            style={_style}
            value={niceNo}
            onChange={this.onNiceNo}
            allowClear
          />
        </div>
        <div className={styles['filter-item']}>
          <h4 className={styles['filter-label']}>是否主播:</h4>
          <Select
            style={_style}
            placeholder='请选择是否主播'
            value={isAnchor}
            onChange={this.onIsAnchor}
            allowClear
          >
            <Option key='all'>全部</Option>
            {
              isAnchorList && isAnchorList.map((item) => (
                <Option key={item.key}>{item.value}</Option>
              ))
            }
          </Select>
        </div>
        <div className={styles['filter-item']}>
          <h4 className={styles['filter-label']}>状态:</h4>
          <Select
            style={_style}
            placeholder='请选择状态'
            value={userStatus}
            onChange={this.onStatusChange}
            allowClear
          >
            <Option key='all'>全部</Option>
            {
              status && status.map((item) => (
                <Option key={item.key}>{item.value}</Option>
              ))
            }
          </Select>
        </div>
        <div className={styles['filter-item']}>
          <h4 className={styles['filter-label']}>排序方式:</h4>
          <Select
            style={_style}
            placeholder='请选择排序方式'
            value={sortType}
            onChange={this.onSortChange}
            allowClear
          >
            {
              sortMethods && sortMethods.map((item) => (
                <Option key={item.key}>{item.value}</Option>
              ))
            }
          </Select>
        </div>
        <div className={`${styles['filter-item']} ${styles['filter-item-time']}`} hidden>
          <h4 className={styles['filter-label']}>创建时间:</h4>
          <RangePicker 
            style={_style}
            onChange={this.onDateChange}
            value={startTime ? [moment(startTime), moment(endTime)] : undefined}
          />
        </div>
        <div className={styles['btn-wrap']}>
          <Button
            icon={<SearchOutlined />}
            onClick={onSearch}
            type='primary'
          >搜索</Button>
        </div>
      </div>
    );
  }
}
export default Filters
