/**
 * 
 * 积分操作
 */
import React, { Component } from 'react'
import { Form } from '@ant-design/compatible';
import '@ant-design/compatible/assets/index.css';
import { Modal, Input, Select, Radio, InputNumber } from 'antd';
import styles from './SetScore.less'
import { reduceScore, addScore } from '../../api'
import { scoreTypeList } from '../../common'

const Option = Select.Option
const _style = {
  width: '100%'
}

// 表单响应配置
const formItemLayout = {
  labelCol: {
    xs: { span: 24 },
    sm: { span: 6 },
  },
  wrapperCol: {
    xs: { span: 24 },
    sm: { span: 16 },
  },
}

@Form.create()
class SetScore extends Component {
  constructor (props) {
    super(props)
    this.state = {}
  }
  componentDidMount () {
    // this.onInitial()
  }
  onInitial = () => {
    // const { wealthLevel, charmLevel, form } = this.props
    // form.setFieldsValue({ wealthLevel, charmLevel })
  }
  // 点击确定 上传数据
  onOk = () => {
    const { form, userId } = this.props 
    if (!userId) {
      return
    }
    form.validateFieldsAndScroll((errors, values) => {
      if (errors) {
        return
      }
      const { 
        scoreValue,
        ...others 
      } = values
      const params = others
      params.userId = userId
      params.scoreValue = scoreValue
      let actionType = 'add'
      if (scoreValue < 0) {
        actionType = 'reduce'
        params.scoreValue = Math.abs(scoreValue)
      }
      this.onPost(params, actionType)
    })
  }
  // 上传数据
  onPost = async (params, actionType) => {
    let _code = ''
    try {
      this.setState({ uploading: true })
      const { code } = actionType === 'add' ? await addScore(params) : await reduceScore(params)
      _code = code
    } catch (e) {
      console.log(e)
    }
    this.setState({ uploading: false })
    if (_code === 'OK') {
      const { onOk } = this.props 
      onOk && onOk()
    }
  }
  render () {
    const { form } = this.props 
    const { getFieldDecorator } = form
    return (
      <Modal
        title='设置积分'
        onCancel={this.props.onCancel}
        onOk={this.onOk}
        visible
      >
        <Form {...formItemLayout}>
          <Form.Item
            label='积分类型'
          >
            {getFieldDecorator('scoreType', {
              rules: [{ required: true, message: '请选择积分类型' }],
            })(
              <Select 
                placeholder='请选择积分类型'
              >
                {
                  scoreTypeList && scoreTypeList.map((item) => (
                    <Option key={item.key}>{item.value}</Option>
                  ))
                }
              </Select>
            )}
          </Form.Item>
          <Form.Item
            label='积分值'
          >
            {getFieldDecorator('scoreValue', {
              rules: [{ required: true, message: '请输入积分值' }],
            })(
              <InputNumber 
                placeholder='请输入积分值(负数为减少积分)'
                step={1}
                precision={0}
                style={_style}
              />
            )}
          </Form.Item>
          {/* <Form.Item
            label='增加/减少'
          >
            {getFieldDecorator('actionType', {
              rules: [{ required: true, message: '请输入积分值' }],
            })(
              <Radio.Group>
                <Radio value='add'>增加</Radio>
                <Radio value='minus'>减少</Radio>
              </Radio.Group>
            )}
          </Form.Item> */}
          <Form.Item
            label='备注'
          >
            {getFieldDecorator('hisRemarks', {
              rules: [{ required: false, message: '请输入备注' }],
            })(
              <Input.TextArea
                placeholder='请输入备注'
              />
            )}
          </Form.Item>
        </Form>
      </Modal>
    )
  }
}
export default SetScore
