/**
 * 
 * 充值记录
 */
import React, { Component } from 'react'
import { PageHeaderWrapper } from '@ant-design/pro-layout'
import styles from './RechargeHis.less'
import { getRechargeHisPageList } from './api'
import { getChannelPageList } from '@/services/manage'
import { Card, Table, Button } from 'antd'
import { RechargeHisFilters } from './components'
import { LeftOutlined } from '@ant-design/icons'
import router from 'umi/router'
import { getPayStatusStr, getDate } from '@/utils/base'

const Column = Table.Column

class RechargeHis extends Component {
  constructor (props) {
    super(props)
    this.state = {
      pagination: {
        current: 1
      },
      startTime: '',
      endTime: '',
    }
  }

  componentDidMount () {
    // this.getChannelPageList()
    this.getRechargeHisPageList()
  }
  getChannelPageList = async () => {
    const _state = {}
    try {
      const { channelId } = this.state
      const _params = {
        channelId, pageIndex: 1, pageSize: 100
      }
      const { code, data } = await getChannelPageList(_params)
      if (code === 'OK') {
        const { list } = data
        
        _state.channelList = list
      }
    } catch (e) {
      console.log(e)
    }
    this.setState(_state)
  }
  getRechargeHisPageList = async () => {
    const _state = { loading: false }
    try {
      const { pagination, tradeId, startTime, endTime } = this.state
      const _params = {
        pageIndex: pagination.current || 1,
        pageSize: 20
      }
      if (tradeId) {
        _params.tradeId = tradeId
      }
      if (startTime) {
        _params.startTime = startTime
        _params.emdTime = endTime
      }
      this.setState({ loading: true })
      const { code, data } = await getRechargeHisPageList(_params)
      if (code === 'OK' && data) {
        const { list, pageIndex, pageSize, total } = data
        list && list.forEach((item) => {
          item.createTimeStr = item.createTime ? getDate(+item.createTime) : '-'
          item.payStatusStr = getPayStatusStr(item.payStatus)
        }) 
        _state.records = list
        _state.pagination = {
          current: pageIndex,
          pageSize, 
          total
        }
      }
    } catch (e) {
      console.log(e)
    }
    this.setState(_state)
  }
  
  // 子组建内容变化
  onChange = (name, value) => {
    if (Array.isArray(name)) {
      let _state = {}
      name.map((item) => {
        _state[item.name] = item.value
      })
      this.setState(_state)
      return
    }
    this.setState({ [name]: value })
  }

  onPageChange = (pagination) => {
    this.setState({ pagination }, this.getRechargeHisPageList)
  }

  // 点击搜索
  onSearch = () => {
    const { pagination } = this.state 
    pagination.current = 1
    this.setState({ pagination }, this.getRechargeHisPageList)
  }
  // 返回
  goBack = () => {
    router.goBack()
  }
  render () {
    const { records, pagination, channelId, channelList, tradeId, startTime,
      endTime, loading
    } = this.state
    // 页码信息
    const { total, current, pageSize } = pagination
    // 石否隐藏 分页信息
    const hidePagination = current === 1 && pageSize >= total
    return (
      <PageHeaderWrapper
        extra={
          <div>
            <Button
              icon={<LeftOutlined />}
              onClick={this.goBack}
            >返回</Button>
          </div>
        }
      >
        <Card>
          <RechargeHisFilters 
            channelList={channelList}
            channelId={channelId}
            tradeId={tradeId}
            startTime={startTime}
            endTime={endTime}
            onChange={this.onChange}
            onSearch={this.onSearch}
          />
          <Table
            bordered
            dataSource={records}
            rowKey='hisId'
            pagination={hidePagination ? false : pagination}
            onChange={this.onPageChange}
            loading={loading}
          >
            <Column 
              title='支付金额(元)'
              key='payAmount'
              dataIndex='payAmount'
            />
            <Column 
              title='充值星钻'
              key='coinAmount'
              dataIndex='coinAmount'
            />
            <Column 
              title='订单状态'
              key='payStatusStr'
              dataIndex='payStatusStr'
            />
            <Column 
              title='创建时间'
              key='createTimeStr'
              dataIndex='createTimeStr'
            />
          </Table>
        </Card>
      </PageHeaderWrapper>
    )
  }
}
export default RechargeHis
