/**
 * 
 * 红包管理
 */
import React, { Component } from 'react'
import { PageHeaderWrapper } from '@ant-design/pro-layout'
import styles from './RedEnvelop.less'
import { Button, Card, Table } from 'antd'
import { PlusOutlined } from '@ant-design/icons'
import { RedEnvelopHisFilters, SendRedEvelop, ShowReceiver } from './components'
import { getRedEnvPageList } from './api'
import { showSuccess, getDate } from '@/utils/base'
import { getRedEvelopStatusStr } from './common'

const Column = Table.Column

class RedEnvelop extends Component {
  constructor (props) {
    super(props)
    this.state = {
      pagination: {
        current: 1
      }
    }
  }
  componentDidMount () {
    this.getRedEnvPageList()
  }
  
  getRedEnvPageList = async () => {
    const _state = { loading: false }
    try {
      const { pagination, tradeId, startTime, endTime } = this.state
      const _params = {
        pageIndex: pagination.current || 1,
        pageSize: 20
      }
      if (tradeId) {
        _params.tradeId = tradeId
      }
      if (startTime) {
        _params.startTime = startTime
        _params.emdTime = endTime
      }
      this.setState({ loading: true })
      const { code, data } = await getRedEnvPageList(_params)
      if (code === 'OK' && data) {
        const { list, pageIndex, pageSize, total } = data
        list && list.forEach((item) => {
          item.createTimeStr = item.createTime ? getDate(+item.createTime) : '-'
          item.statusStr = getRedEvelopStatusStr(item.status)
        })
        _state.records = list
        _state.pagination = {
          current: pageIndex,
          pageSize, 
          total
        }
      }
    } catch (e) {
      console.log(e)
    }
    this.setState(_state)
  }

  onPageChange = (pagination) => {
    this.setState({ pagination }, this.getRedEnvPageList)
  }

  // 子组建内容变化
  onChange = (name, value) => {
    if (Array.isArray(name)) {
      let _state = {}
      name.map((item) => {
        _state[item.name] = item.value
      })
      this.setState(_state)
      return
    }
    this.setState({ [name]: value })
  }
  // 发红包
  sendRedEvelop = () => {
    SendRedEvelop({
      onOk: () => {
        this.getRedEnvPageList()
        showSuccess('红包发送成功')
      }
    })
  }

  // 点击搜索
  onSearch = () => {
    const { pagination } = this.state 
    pagination.current = 1
    this.setState({ pagination }, this.getRedEnvPageList)
  }

  // 点击查看接收者
  showReceiver = ({ details }) => {
    ShowReceiver({
      details
    })
  }
  render () {
    const { 
      channelList, channelId, tradeId, startTime, endTime, records, pagination,
      loading
    } = this.state
    // 页码信息
    const { total, current, pageSize } = pagination
    // 石否隐藏 分页信息
    const hidePagination = current === 1 && pageSize >= total
    return (
      <PageHeaderWrapper
        extra={
          <div>
            <Button
              type='primary'
              icon={<PlusOutlined />}
              onClick={this.sendRedEvelop}
            >发红包</Button>
          </div>
        }
      >
        <Card>
          <RedEnvelopHisFilters 
            channelList={channelList}
            channelId={channelId}
            tradeId={tradeId}
            startTime={startTime}
            endTime={endTime}
            onChange={this.onChange}
            onSearch={this.onSearch}
          />
          <Table
            bordered
            dataSource={records}
            rowKey='hisId'
            pagination={hidePagination ? false : pagination}
            onChange={this.onPageChange}
            loading={loading}
          >
            <Column 
              title='发送类型'
              key='sendType'
              dataIndex='sendType'
              render={(sendType) => (
                sendType === 1 
                ? '管理员' 
                : sendType === 2 
                  ? '接口调用' : '-'
              )}
            />
            <Column 
              title='交易ID'
              key='tradeId'
              dataIndex='tradeId'
              render={(tradeId) => (tradeId || '-')}
            />
            <Column 
              title='红包发放总额(星钻)'
              key='totalAmount'
              dataIndex='totalAmount'
            />
            
            <Column 
              title='状态'
              key='statusStr'
              dataIndex='statusStr'
            />
            <Column 
              title='备注'
              key='remark'
              dataIndex='remark'
              width='20%'
            />
            <Column 
              title='接收者'
              key='details'
              dataIndex='details'
              render={(text, record) => (
                <a 
                  href='#' 
                  onClick={(e) => {
                    e.preventDefault()
                    this.showReceiver(record)
                  }}
                >点击查看</a>
              )}
            />
            <Column 
              title='创建时间'
              key='createTimeStr'
              dataIndex='createTimeStr'
            />
            <Column 
              title='发放者'
              key='adminName'
              dataIndex='adminName'
              render={(adminName) => (adminName || '-')}
            />
            
          </Table>
        </Card>
      </PageHeaderWrapper>
    )
  }
}
export default RedEnvelop
