/**
 * 
 * 钱包查询
 */
import React, { Component } from 'react'
import { PageHeaderWrapper } from '@ant-design/pro-layout';
import styles from './WalletSearch.less'
import { Card, Descriptions, Table, Button } from 'antd'
import { walletGetInfo, getWalletHisPageList, getExchangeHisPageList } from './api'
import { getChannelPageList } from '@/services/manage'
import { connect } from 'dva'
import { WalletSearchFilters, WalletRecharge } from './components'
import { PlusOutlined } from '@ant-design/icons'
import router from 'umi/router'
import { showSuccess, getDate } from '@/utils/base'

const Column = Table.Column
const _cardStyle = {
  marginBottom: 10
}
class WalletSearch extends Component {
  constructor (props) {
    super(props)
    this.state = {
      pagination: {
        current: 1
      }
    }
  }
  componentDidMount () {
    this.walletGetInfo()
    this.getWalletHisPageList()
  }
  walletGetInfo = async () => {
    const _state = {}
    try {
      // const { channelId } = this.state
      const { code, data } = await walletGetInfo()
      if (code === 'OK' && data) {
        const { balance, availableBalance, freeze } = data
        _state.balance =balance
        _state.freeze = freeze
        _state.availableBalance = availableBalance
      }
    } catch (e) {
      console.log(e)
    }
    this.setState(_state)
  }

  getWalletHisPageList = async () => {
    const _state = { loading: false }
    try {
      const { pagination, tradeId, startTime, endTime } = this.state
      const _params = {
        // channelId, // : '79540193853440',
        pageIndex: pagination.current || 1,
        pageSize: 20
      }
      if (tradeId) {
        _params.tradeId = tradeId
      }
      if (startTime) {
        _params.startTime = startTime
        _params.endTime = endTime
      }
      this.setState({ loading: true })
      const { code, data } = await getWalletHisPageList(_params)
      if (code === 'OK' && data) {
        const { list, pageIndex, pageSize, total } = data
        list && list.forEach((item) => {
          item.createTimeStr = item.createTime ? getDate(+item.createTime) : ''
        })
        _state.records = list
        _state.pagination = {
          current: pageIndex,
          pageSize, 
          total
        }
      }
    } catch (e) {
      console.log(e)
    }
    this.setState(_state)
  }
  
  // 子组建内容变化
  onChange = (name, value) => {
    if (Array.isArray(name)) {
      let _state = {}
      name.map((item) => {
        _state[item.name] = item.value
      })
      this.setState(_state)
      return
    }
    this.setState({ [name]: value })
  }

  onPageChange = (pagination) => {
    this.setState({ pagination }, this.getWalletHisPageList)
  }
  // 点击搜索
  onSearch = () => {
    const { pagination } = this.state 
    pagination.current = 1
    this.setState({ pagination }, this.getWalletHisPageList)
  }

  // 跳转到充值流水
  goRecords = () => {
    router.push({
      pathname: '/finance/walletSearch/rechargeHis'
    })
  }
  // 充值
  onRecharge = () => {
    WalletRecharge({
      reloadData: () => {
        this.walletGetInfo()
        this.getWalletHisPageList()
      }
    })
  }
  
  render () {
    const { 
      balance, records, channelId, startTime, endTime, loading, pagination = {}, 
      channelList
    } = this.state
    // 页码信息
    const { total, current, pageSize } = pagination
    // 石否隐藏 分页信息
    const hidePagination = current === 1 && pageSize >= total
    return (
      <PageHeaderWrapper
        extra={
          <div className={styles['action-wrap']}>
            <Button
              type='primary'
              icon={<PlusOutlined />}
              onClick={this.onRecharge}
            >充值</Button>
            <Button
              onClick={this.goRecords}
            >充值流水</Button>
          </div>
        }
      >
        <Card title='钱包信息' style={_cardStyle}>
          {/* <WalletSearchFilters 
            channelId={channelId} 
            onChange={this.onChange}
            onSearch={this.onSearch}
            channelList={channelList}
            hiddenTime
          /> */}
          <Descriptions bordered>
            <Descriptions.Item label='总额'>
              {balance}
            </Descriptions.Item>
            
          </Descriptions>
        </Card>
        <Card title='钱包流水'>
          <WalletSearchFilters 
            channelId={channelId} 
            startTime={startTime} 
            endTime={endTime}
            channelList={channelList}
            onChange={this.onChange}
            onSearch={this.onSearch}
          />

          <Table
            bordered
            dataSource={records}
            rowKey='hisId'
            pagination={hidePagination ? false : pagination}
            onChange={this.onPageChange}
            loading={loading}
          >
            <Column 
              title='充值星钻'
              key='balanceValue'
              dataIndex='balanceValue'
            />
            <Column 
              title='充值前余额'
              key='balanceOld'
              dataIndex='balanceOld'
            />
            <Column 
              title='充值后余额'
              key='balanceNew'
              dataIndex='balanceNew'
            />
            <Column 
              title='备注'
              key='hisRemarks'
              dataIndex='hisRemarks'
              width='20%'
            />
            <Column 
              title='创建时间'
              key='createTimeStr'
              dataIndex='createTimeStr'
            />
          </Table>
        </Card>
      </PageHeaderWrapper>
    )
  }
}
export default WalletSearch
