/**
 * 充值
 */
import React, { Component } from 'react'
import styles from './WalletRecharge.less'
import { Drawer, Button, InputNumber, Form, Result } from 'antd'
import { channelWalletRecharge, getPayStatus } from '../../api'
import QRCode from 'qrcode.react'
import iconZhi from '@/assets/icon_zhi.png'

const FormItem = Form.Item
const formItemLayout = {
  labelCol: { xs: { span: 24, }, sm: { span: 6, }, },
  wrapperCol: { 
    xs: { span: 24, },
    sm: { span: 14, },
    md: { span: 14, },
  },
}
const itemStyle = {
  width: '100%'
}

// 底部按钮样式
const _btnStyle = {
  width: 110,
  margin: '0 10px'
}

class WalletRecharge extends Component {
  constructor (props) {
    super(props)
    this.state = {
      uploading: false,
      qrCodeUrl: undefined,
      payResult: '',
      payResultTitle: ''
    }
  }
  formRef = React.createRef()
  componentDidMount () {
    
  }

  // 获取订单状态
  // 返回值 11:待支付; 21:支付失败; 22:支付取消; 99:支付成功
  loopGetOrderStatus = async () => {
    const { orderId } = this.state
    
    try {
      const { code, data } = await getPayStatus({ orderId })
      if (code === 'OK') {
        if (data === 11) {
          // 待支付 继续请求
          // 超时不耍接口
          const minStamp = 2 * 60 * 1000
          if (new Date().getTime() - this.loopTimeStamp >= minStamp) {
            // 超时
            this.setState({
              payResult: 'warning', payResultTitle: '充值超时'
            })
            return
          }
          this.loopTimer = setTimeout(this.loopGetOrderStatus, 1000)
        }
        if (data === 21) {
          // 支付失败
          this.setState({ payResult: 'error', payResultTitle: '充值失败' })
        }
        if (data === 22) {
          // 支付取消
          this.setState({ payResult: 'error', payResultTitle: '充值失败' })
        }
        if (data === 99) {
          // 支付成功
          this.setState({ payResult: 'success', payResultTitle: '充值成功' })
          const { reloadData } = this.props
          reloadData && reloadData()
        }
      }
    } catch (e) {
      console.log(e)
    }
  }
  
  onOk = async () => {
    try {
      const values = await this.formRef.current.validateFields()
      const { onOk } = this.props
      this.setState({ uploading: true })
      const { code, data } = await channelWalletRecharge(values)
      if (code === 'OK' && data){
        // 更新成功
        const { qrCode, orderId, payId } = data
        this.setState({
          orderId, 
          payId,
          qrCodeUrl: qrCode
        }, () => {
          this.okTimer = setTimeout(() => {
            this.loopTimeStamp = new Date().getTime()
            this.loopGetOrderStatus()
          }, 1500)
        })
        // onOk && onOk()
      }
    } catch (e) {
      console.log(e)
    }
    this.setState({ uploading: false })
  }
  componentWillUnmount () {
    clearTimeout(this.loopTimer)
    clearTimeout(this.okTimer)
  }
  render () {
    const { uploading, qrCodeUrl, payResult, payResultTitle } = this.state
    const { onCancel } = this.props
    const amount = this.formRef && this.formRef.current ? this.formRef.current.getFieldValue('amount') : 0

    return (
      <Drawer
        width={520}
        visible
        title='充值'
        maskClosable={false}
        onClose={onCancel}
      >
        <div className={styles['content-wrap']} hidden={qrCodeUrl}>
          <Form ref={this.formRef} {...formItemLayout}>
            <FormItem
              label="金额"
              name="amount"
              rules={[{ required: true, message: '请输入充值金额' }]}
            >
              <InputNumber 
                placeholder='请输入充值金额' 
                precision={0}
                min={0}
                style={itemStyle}
              />
            </FormItem>
          </Form>
          <div className={styles['footer-wrap']}>
            <Button
              style={_btnStyle}
              onClick={onCancel}
            >取消</Button>
            <Button
              type='primary'
              style={_btnStyle}
              onClick={uploading ? null : this.onOk}
              loading={uploading}
            >确定</Button>
          </div>
        </div>
        {
          !!qrCodeUrl &&
          <div className={styles['ali-content-wrap']}>
            <div hidden={payResult}>
              <div className={styles['money-notice']}>
                <div>扫码付款 (元)</div>
                <p className={styles['money-wrap']}>{amount}</p>
              </div>
              <div className={styles['qrcode-info-wrap']}>
                <div className={styles['qrcode-wrap']}>
                  <QRCode 
                    value={qrCodeUrl} 
                    id='qcode'
                    size={168}
                    renderAs='canvas'
                    level='H'
                  />
                  <img className={styles['icon-inner']} src={iconZhi} alt="" />
                </div>
                <div className={styles['alipay-scan-notice']}>
                  <div>打开手机支付宝</div>
                  <div>扫一扫继续付款</div>
                  <div>请在2分钟内完成付款</div>
                </div>
              </div>
            </div>

            <div hidden={!payResult}>
              <Result 
                status={payResult || 'success'}
                title={payResultTitle}
                subTitle={payResult === 'error' || payResult === 'warning' ? '请关闭弹窗重新充值': ''}
              />
            </div> 
          </div>
        }
      </Drawer>
    )
  }
}
export default WalletRecharge
